searchData={"items":[{"type":"module","doc":"high-level module providing a convenient and efficient interface for interacting\nwith the Ethereum blockchain using Elixir.\n\nThis module offers a simple API for common Ethereum operations such as deploying contracts,\nfetching current gas prices, and querying event logs.","title":"Ethers","ref":"Ethers.html"},{"type":"module","doc":"Often you would find yourself executing different actions without dependency. These actions can\nbe combined together in one JSON RPC call. This will save on the number of round trips and\nimproves latency.\n\nBefore continuing, please note that batching JSON RPC requests and using `Ethers.Multicall` are\ntwo different things. As a rule of thumb:\n\n- Use `Ethers.Multicall` if you need to make multiple contract calls and get the result\n  *on the same block*.\n- Use `Ethers.batch/2` if you need to make multiple JSON RPC operations which may or may not run\n  on the same block (or even be related to any specific block e.g. eth_gas_price)","title":"Batching Requests - Ethers","ref":"Ethers.html#module-batching-requests"},{"type":"module","doc":"`Ethers.batch/2` supports all operations which the RPC module (`Ethereumex` by default)\nimplements. Although some actions support pre and post processing and some are just forwarded\nto the RPC module.\n\nEvery request passed to `Ethers.batch/2` can be in one of the following formats\n\n- `action_name_atom`: This only works with requests which do not require any additional data.\n  e.g. `:current_gas_price` or `:net_version`.\n- `{action_name_atom, data}`: This works with all other actions which accept input data.\n  e.g. `:call`, `:send_transaction` or `:get_logs`.\n- `{action_name_atom, data, overrides_keyword_list}`: Use this to override or add attributes\n  to the action data. This is only accepted for these actions and will through error on others.\n  - `:call`: data should be a Ethers.TxData struct and overrides are accepted.\n  - `:estimate_gas`: data should be a Ethers.TxData struct or a map and overrides are accepted.\n  - `:get_logs`: data should be a Ethers.EventFilter struct and overrides are accepted.\n  - `:send_transaction`: data should be a Ethers.TxData struct and overrides are accepted.","title":"Make batch requests - Ethers","ref":"Ethers.html#module-make-batch-requests"},{"type":"module","doc":"```elixir\nEthers.batch([\n  :current_block_number,\n  :current_gas_price,\n  {:call, Ethers.Contracts.ERC20.name(), to: \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\"},\n  {:send_transaction, MyContract.ping(), from: \"0xd8dA6BF26964aF9D7eEd9e03E53415D37aA96045\"},\n  {:get_logs, Ethers.Contracts.ERC20.EventFilters.approval(nil, nil)} # <- can have add overrides\n])\n{:ok, [\n  {:ok, 18539069},\n  {:ok, 21221},\n  {:ok, \"Wrapped Ether\"},\n  {:ok, \"0xed67b1aafdc823077166c8ee9da13c6a621d19f4d7a24a80353219c09bdac87f\"},\n  {:ok, [%Ethers.EventFilter{}]}\n]}\n```","title":"Example - Ethers","ref":"Ethers.html#module-example"},{"type":"function","doc":"Combines multiple requests and make a batch json RPC request.\n\nIt returns `{:ok, results}` in case of success or `{:error, reason}` in case of RPC failure.\n\nEach action will have an entry in the results. Each entry is again a tuple and either\n`{:ok, result}` or `{:error, reason}` in case of action failure.\n\nCheckout `Batching Requests` sections in `Ethers` module for more examples.","title":"Ethers.batch/2","ref":"Ethers.html#batch/2"},{"type":"function","doc":"- requests: A list of requests to execute.\n- opts: RPC related options. (No account and block options are accepted in batch)","title":"Parameters - Ethers.batch/2","ref":"Ethers.html#batch/2-parameters"},{"type":"function","doc":"An action can be in either of the following formats.\n\n- `{action_name_atom, action_data, action_overrides}`\n- `{action_name_atom, action_data}`\n- `action_name_atom`","title":"Action - Ethers.batch/2","ref":"Ethers.html#batch/2-action"},{"type":"function","doc":"```elixir\nEthers.batch([\n  {:call, WETH.name()},\n  {:call, WETH.symbol(), to: \"[WETH ADDRESS]\"},\n  {:send_transaction, WETH.transfer(\"[RECEIVER]\", 1000), from: \"[SENDER]\"},\n  :current_block_number\n])\n{:ok, [ok: \"Weapped Ethereum\", ok: \"WETH\", ok: \"0xhash...\", ok: 182394532]}\n```","title":"Examples - Ethers.batch/2","ref":"Ethers.html#batch/2-examples"},{"type":"function","doc":"Same as `Ethers.batch/2` but raises on error.","title":"Ethers.batch!/2","ref":"Ethers.html#batch!/2"},{"type":"function","doc":"Returns the current blob base fee from the RPC API","title":"Ethers.blob_base_fee/1","ref":"Ethers.html#blob_base_fee/1"},{"type":"function","doc":"Same as `Ethers.blob_base_fee/1` but raises on error.","title":"Ethers.blob_base_fee!/1","ref":"Ethers.html#blob_base_fee!/1"},{"type":"function","doc":"Makes an eth_call to with the given `Ethers.TxData` struct and overrides. It then parses\nthe response using the selector in the TxData struct.","title":"Ethers.call/2","ref":"Ethers.html#call/2"},{"type":"function","doc":"Other than what stated below, any other option given in the overrides keyword list will be merged\nwith the map that the RPC client will receive.\n\n- `:to`: Indicates recipient address. (Contract address in this case)\n- `:block`: The block number or block alias. Defaults to `latest`\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)","title":"Overrides and Options - Ethers.call/2","ref":"Ethers.html#call/2-overrides-and-options"},{"type":"function","doc":"For contract functions which return a single value (e.g. `function test() returns (uint)`) this\nreturns `{:ok, value}` and for the functions which return multiple values it will return\n`{:ok, [value0, value1]}` (A list).","title":"Return structure - Ethers.call/2","ref":"Ethers.html#call/2-return-structure"},{"type":"function","doc":"```elixir\nEthers.Contract.ERC20.total_supply() |> Ethers.call(to: \"0xa0b...ef6\")\n{:ok, 100000000000000}\n```","title":"Examples - Ethers.call/2","ref":"Ethers.html#call/2-examples"},{"type":"function","doc":"Same as `Ethers.call/2` but raises on error.","title":"Ethers.call!/2","ref":"Ethers.html#call!/2"},{"type":"function","doc":"","title":"Ethers.chain_id/1","ref":"Ethers.html#chain_id/1"},{"type":"function","doc":"Same as `Ethers.chain_id/1` but raises on error.","title":"Ethers.chain_id!/1","ref":"Ethers.html#chain_id!/1"},{"type":"function","doc":"Returns the current block number of the blockchain.","title":"Ethers.current_block_number/1","ref":"Ethers.html#current_block_number/1"},{"type":"function","doc":"Returns the current gas price from the RPC API","title":"Ethers.current_gas_price/1","ref":"Ethers.html#current_gas_price/1"},{"type":"function","doc":"Deploys a contract to the blockchain.\n\nThis will return the transaction hash for the deployment transaction.\nTo get the address of your deployed contract, use `Ethers.deployed_address/2`.\n\nTo deploy a cotract you must have the binary related to it. It can either be a part of the ABI\nFile you have or as a separate file.","title":"Ethers.deploy/2","ref":"Ethers.html#deploy/2"},{"type":"function","doc":"- contract_module_or_binary: Either the contract module which was already loaded or the compiled\nbinary of the contract. The binary MUST be hex encoded.\n- overrides: A keyword list containing options and overrides.\n  - `:encoded_constructor`: Hex encoded value for constructor parameters. (See `constructor`\n    function of the contract module)\n  - All other options from `Ethers.send_transaction/2`","title":"Parameters - Ethers.deploy/2","ref":"Ethers.html#deploy/2-parameters"},{"type":"function","doc":"Returns the address of the deployed contract if the deployment is finished and successful","title":"Ethers.deployed_address/2","ref":"Ethers.html#deployed_address/2"},{"type":"function","doc":"- tx_hash: Hash of the Transaction which created a contract.\n- opts: RPC and account options.","title":"Parameters - Ethers.deployed_address/2","ref":"Ethers.html#deployed_address/2-parameters"},{"type":"function","doc":"Makes an eth_estimate_gas rpc call with the given parameters and overrides.","title":"Ethers.estimate_gas/2","ref":"Ethers.html#estimate_gas/2"},{"type":"function","doc":"- `:to`: Indicates recipient address. (Contract address in this case)\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)\n\n```elixir\nEthers.Contract.ERC20.transfer(\"0xff0...ea2\", 1000) |> Ethers.estimate_gas(to: \"0xa0b...ef6\")\n{:ok, 12345}\n```","title":"Overrides and Options - Ethers.estimate_gas/2","ref":"Ethers.html#estimate_gas/2-overrides-and-options"},{"type":"function","doc":"Same as `Ethers.estimate_gas/2` but raises on error.","title":"Ethers.estimate_gas!/2","ref":"Ethers.html#estimate_gas!/2"},{"type":"function","doc":"Returns the native token (ETH) balance of an account in wei.","title":"Ethers.get_balance/2","ref":"Ethers.html#get_balance/2"},{"type":"function","doc":"- account: Account which the balance is queried for.\n- overrides:\n  - block: The block you want to query the balance of account in (defaults to `latest`).\n  - rpc_client: The RPC module to use for this request (overrides default).\n  - rpc_opts: Specific RPC options to specify for this request.","title":"Parameters - Ethers.get_balance/2","ref":"Ethers.html#get_balance/2-parameters"},{"type":"function","doc":"Same as `Ethers.get_balance/2` but raises on error.","title":"Ethers.get_balance!/2","ref":"Ethers.html#get_balance!/2"},{"type":"function","doc":"Fetches the event logs with the given filter.","title":"Ethers.get_logs/2","ref":"Ethers.html#get_logs/2"},{"type":"function","doc":"- `:address`: Indicates event emitter contract address. (nil means all contracts)\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)\n- `:fromBlock` | `:from_block`: Minimum block number of logs to filter.\n- `:toBlock` | `:to_block`: Maximum block number of logs to filter.","title":"Overrides and Options - Ethers.get_logs/2","ref":"Ethers.html#get_logs/2-overrides-and-options"},{"type":"function","doc":"Same as `Ethers.get_logs/2` but raises on error.","title":"Ethers.get_logs!/2","ref":"Ethers.html#get_logs!/2"},{"type":"function","doc":"Returns the native transaction (ETH) by transaction hash.","title":"Ethers.get_transaction/2","ref":"Ethers.html#get_transaction/2"},{"type":"function","doc":"- tx_hash: Transaction hash which the transaction is queried for.\n- overrides:\n  - rpc_client: The RPC module to use for this request (overrides default).\n  - rpc_opts: Specific RPC options to specify for this request.","title":"Parameters - Ethers.get_transaction/2","ref":"Ethers.html#get_transaction/2-parameters"},{"type":"function","doc":"Same as `Ethers.get_transaction/2` but raises on error.","title":"Ethers.get_transaction!/2","ref":"Ethers.html#get_transaction!/2"},{"type":"function","doc":"Returns the transaction count of an address.","title":"Ethers.get_transaction_count/2","ref":"Ethers.html#get_transaction_count/2"},{"type":"function","doc":"- account: Account which the transaction count is queried for.\n- overrides:\n  - block: The block you want to query the transaction count in (defaults to latest).\n  - rpc_client: The RPC module to use for this request (overrides default).\n  - rpc_opts: Specific RPC options to specify for this request.","title":"Parameters - Ethers.get_transaction_count/2","ref":"Ethers.html#get_transaction_count/2-parameters"},{"type":"function","doc":"Returns the receipt of a transaction by it's hash.","title":"Ethers.get_transaction_receipt/2","ref":"Ethers.html#get_transaction_receipt/2"},{"type":"function","doc":"- tx_hash: Transaction hash which the transaction receipt is queried for.\n- overrides:\n  - rpc_client: The RPC module to use for this request (overrides default).\n  - rpc_opts: Specific RPC options to specify for this request.","title":"Parameters - Ethers.get_transaction_receipt/2","ref":"Ethers.html#get_transaction_receipt/2-parameters"},{"type":"function","doc":"Same as `Ethers.get_transaction_receipt/2` but raises on error.","title":"Ethers.get_transaction_receipt!/2","ref":"Ethers.html#get_transaction_receipt!/2"},{"type":"function","doc":"Returns the current max priority fee per gas from the RPC API","title":"Ethers.max_priority_fee_per_gas/1","ref":"Ethers.html#max_priority_fee_per_gas/1"},{"type":"function","doc":"Same as `Ethers.max_priority_fee_per_gas/1` but raises on error.","title":"Ethers.max_priority_fee_per_gas!/1","ref":"Ethers.html#max_priority_fee_per_gas!/1"},{"type":"function","doc":"","title":"Ethers.send/2","ref":"Ethers.html#send/2"},{"type":"function","doc":"","title":"Ethers.send!/2","ref":"Ethers.html#send!/2"},{"type":"function","doc":"Makes an eth_send rpc call to with the given data and overrides, Then returns the\ntransaction hash.","title":"Ethers.send_transaction/2","ref":"Ethers.html#send_transaction/2"},{"type":"function","doc":"Other than what stated below, any other option given in the overrides keyword list will be merged\nwith the map that the RPC client will receive.","title":"Overrides and Options - Ethers.send_transaction/2","ref":"Ethers.html#send_transaction/2-overrides-and-options"},{"type":"function","doc":"- `:from`: The address of the account to sign the transaction with.","title":"Required Options - Ethers.send_transaction/2","ref":"Ethers.html#send_transaction/2-required-options"},{"type":"function","doc":"- `:access_list`: List of storage slots that this transaction accesses (optional)\n- `:chain_id`: Chain id for the transaction (defaults to chain id from RPC server).\n- `:gas_price`: (legacy only) max price willing to pay for each gas.\n- `:gas`: Gas limit for execution of this transaction.\n- `:max_fee_per_gas`: (EIP-1559 only) max fee per gas (defaults to 120% current gas price estimate).\n- `:max_priority_fee_per_gas`: (EIP-1559 only) max priority fee per gas or validator tip. (defaults to zero)\n- `:nonce`: Nonce of the transaction. (defaults to number of transactions of from address)\n- `:rpc_client`: The RPC Client to use. It should implement ethereum jsonRPC API. default: Ethereumex.HttpClient\n- `:rpc_opts`: Extra options to pass to rpc_client. (Like timeout, Server URL, etc.)\n- `:signer`: The signer module to use for signing transaction. Default is nil and will rely on the RPC server for signing.\n- `:signer_opts`: Options for signer module. See your signer docs for more details.\n- `:type`: Transaction type. Either `Ethers.Transaction.Eip1559` (default) or `Ethers.Transaction.Legacy`.\n- `:to`: Address of the contract or a receiver of this transaction. (required if TxData does not have default_address)\n- `:value`: Ether value to send with the transaction to the receiver (`from => to`).","title":"Optional Options - Ethers.send_transaction/2","ref":"Ethers.html#send_transaction/2-optional-options"},{"type":"function","doc":"```elixir\nEthers.Contract.ERC20.transfer(\"0xff0...ea2\", 1000) |> Ethers.send_transaction(to: \"0xa0b...ef6\")\n{:ok, _tx_hash}\n```","title":"Examples - Ethers.send_transaction/2","ref":"Ethers.html#send_transaction/2-examples"},{"type":"function","doc":"Same as `Ethers.send_transaction/2` but raises on error.","title":"Ethers.send_transaction!/2","ref":"Ethers.html#send_transaction!/2"},{"type":"function","doc":"Signs a transaction and returns the encoded signed transaction hex.","title":"Ethers.sign_transaction/2","ref":"Ethers.html#sign_transaction/2"},{"type":"function","doc":"Accepts same parameters as `Ethers.send_transaction/2`.","title":"Parameters - Ethers.sign_transaction/2","ref":"Ethers.html#sign_transaction/2-parameters"},{"type":"function","doc":"Same as `Ethers.sign_transaction/2` but raises on error.","title":"Ethers.sign_transaction!/2","ref":"Ethers.html#sign_transaction!/2"},{"type":"type","doc":"","title":"Ethers.t_batch_request/0","ref":"Ethers.html#t:t_batch_request/0"},{"type":"module","doc":"CCIP Read ([EIP-3668](https://eips.ethereum.org/EIPS/eip-3668)) implementation\n\nNOTE: Currently supports URLs with \"https\" scheme only","title":"Ethers.CcipRead","ref":"Ethers.CcipRead.html"},{"type":"function","doc":"Same as `Ethers.call/2` but will handle `Ethers.Contacts.CcipRead.Errors.OffchainLookup` errors\nand performs an offchain lookup as per [EIP-3668](https://eips.ethereum.org/EIPS/eip-3668) specs.","title":"Ethers.CcipRead.call/2","ref":"Ethers.CcipRead.html#call/2"},{"type":"function","doc":"Accepts same options as `Ethers.call/2`","title":"Options and Overrides - Ethers.CcipRead.call/2","ref":"Ethers.CcipRead.html#call/2-options-and-overrides"},{"type":"module","doc":"Dynamically creates modules for ABIs at compile time.","title":"Ethers.Contract","ref":"Ethers.Contract.html"},{"type":"module","doc":"You can simply create a new module and call `use Ethers.Contract` in it with the desired parameters.\n\n```elixir\n# Using an ABI file\ndefmodule MyProject.Contract do\n  use Ethers.Contract, abi_file: \"path/to/abi.json\"\nend\n\n# Providing a default address\ndefmodule MyProject.Contract do\n  use Ethers.Contract, abi_file: \"path/to/abi.json\", default_address: \"0x1234...999\"\nend\n\n# Using an ABI directly\ndefmodule MyProject.Contract do\n  use Ethers.Contract, abi: [%{\"inputs\" => [], \"type\" => \"constructor\"}, ...]\nend\n```\n\nAfter this, the functions in your contracts should be accessible just by calling\n```elixir\ndata = MyProject.Contract.example_function(...)\n\n# Use data to handle eth_call\nEthers.call(data, to: \"0xADDRESS\", from: \"0xADDRESS\")\n{:ok, [...]}\n```","title":"How to use - Ethers.Contract","ref":"Ethers.Contract.html#module-how-to-use"},{"type":"module","doc":"- `abi`: Used to pass in the decoded (or even encoded json binary) ABI of contract.\n- `abi_file`: Used to pass in the file path to the json ABI of contract.\n- `default_address`: Default contract deployed address to include in the parameters. (Optional)\n- `skip_docs`: Determines if Ethers should skip generating docs and typespecs. (Default: false)\n  - `true`: Skip docs and typespecs for all functions.\n  - `false`: Generate docs and typespecs for all functions.\n  - `[{function_name :: atom(), skip_docs :: boolean()}]`: Specify for each function.","title":"Valid `use` options - Ethers.Contract","ref":"Ethers.Contract.html#module-valid-use-options"},{"type":"module","doc":"EVM Event struct and helpers","title":"Ethers.Event","ref":"Ethers.Event.html"},{"type":"function","doc":"Decodes a log entry with the given Event function selector and returns an Event struct","title":"Ethers.Event.decode/2","ref":"Ethers.Event.html#decode/2"},{"type":"function","doc":"Given a log entry and an EventFilters module (e.g. `Ethers.Contracts.ERC20.EventFilters`)\nwill find a matching event filter in the given module and decodes the log using the event selector.","title":"Ethers.Event.find_and_decode/2","ref":"Ethers.Event.html#find_and_decode/2"},{"type":"type","doc":"","title":"Ethers.Event.t/0","ref":"Ethers.Event.html#t:t/0"},{"type":"module","doc":"Event Filter struct and helper functions to work with the event filters","title":"Ethers.EventFilter","ref":"Ethers.EventFilter.html"},{"type":"type","doc":"Holds event filter topics, the event selector and the default address.\n\nCan be passed in to `Ethers.get_logs/2` filter and fetch the logs.","title":"Ethers.EventFilter.t/0","ref":"Ethers.EventFilter.html#t:t/0"},{"type":"module","doc":"This module offers convenient utilities and a user-friendly API for interacting with\n`Multicall3` (for more information, visit https://www.multicall3.com).\n\nThe primary function of this module is to aggregate multiple Ethereum contract calls\ninto a single operation. This aggregated call can be subsequently submitted using `Ethers.call/2`\nor `Ethers.send_transaction/2` (If you know what you are doing!).\n\nUpon receiving the response, it can be decoded using `Ethers.Multicall.decode/2` to interpret the\nresults returned by the `Multicall3` contract.","title":"Ethers.Multicall","ref":"Ethers.Multicall.html"},{"type":"module","doc":"```elixir\ncalls = [\n  ContractA.foo(),\n  {ContractB.foo(), to: \"0x...\"},\n]\n\ncalls\n|> Ethers.Multicall.aggregate3() # Or `Ethers.Multicall.aggregate2/1`\n|> Ethers.call!()\n|> Ethers.Multicall.decode(calls)\n```","title":"How to use - Ethers.Multicall","ref":"Ethers.Multicall.html#module-how-to-use"},{"type":"function","doc":"Aggregate calls, returning the executed block number and will revert if any\ncall fails. Returns a `Ethers.TxData` struct which can be passed to `Ethers.call/2`.\n\nFor more information refer to https://github.com/mds1/multicall#batch-contract-reads","title":"Ethers.Multicall.aggregate2/1","ref":"Ethers.Multicall.html#aggregate2/1"},{"type":"function","doc":"- data: A list of `TxData` structs or `{%TxData{...}, options}` tuples. The options can include:\n  - to: Overrides the `default_address` (if any) for the respective function call.","title":"Parameters - Ethers.Multicall.aggregate2/1","ref":"Ethers.Multicall.html#aggregate2/1-parameters"},{"type":"function","doc":"```elixir\nEthers.Multicall.aggregate2([\n  ContractA.foo(), # <-- Assumes `default_address` in ContractA is defined.\n  { ContractB.bar(), to: \"0x...\" }, # <-- ContractB.bar() will call `to`.\n])\n#Ethers.TxData \n```","title":"Examples - Ethers.Multicall.aggregate2/1","ref":"Ethers.Multicall.html#aggregate2/1-examples"},{"type":"function","doc":"Decodes an `aggregate2/2` response from `Ethers.call/2`.","title":"Ethers.Multicall.aggregate2_decode/2","ref":"Ethers.Multicall.html#aggregate2_decode/2"},{"type":"function","doc":"- resps: The response from `Ethers.call/2`.\n- calls: A list of the function calls or signatures passed to `aggregate2/2`.","title":"Parameters - Ethers.Multicall.aggregate2_decode/2","ref":"Ethers.Multicall.html#aggregate2_decode/2-parameters"},{"type":"function","doc":"```elixir\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls\n|> Ethers.Multicall.aggregate2()\n|> Ethers.call!()\n|> Ethers.Multicall.aggregate2_decode(calls)\n[ 1337, [ \"bar\", \"baz\" ]]\n```","title":"Examples - Ethers.Multicall.aggregate2_decode/2","ref":"Ethers.Multicall.html#aggregate2_decode/2-examples"},{"type":"function","doc":"Encodes a function call with optional options into a solidity compatible (address,bytes).","title":"Ethers.Multicall.aggregate2_encode_data/1","ref":"Ethers.Multicall.html#aggregate2_encode_data/1"},{"type":"function","doc":"- data:  A `TxData` structs or `{%TxData{...}, options}` tuple. The options can include:\n  - to: Overrides the `default_address` (if any) for the respective function call.","title":"Parameters - Ethers.Multicall.aggregate2_encode_data/1","ref":"Ethers.Multicall.html#aggregate2_encode_data/1-parameters"},{"type":"function","doc":"```elixir\n{ ContractA.foo(), to: \"0x1337...\" } |> aggregate2_encode_data()\n{\"0x1337...\", false, <<...>>}\n\nContractB.bar() |> aggregate2_encode_data()\n{\"0x...\", <<...>>}\n```","title":"Examples - Ethers.Multicall.aggregate2_encode_data/1","ref":"Ethers.Multicall.html#aggregate2_encode_data/1-examples"},{"type":"type","doc":"","title":"Ethers.Multicall.aggregate2_option/0","ref":"Ethers.Multicall.html#t:aggregate2_option/0"},{"type":"function","doc":"Aggregates calls, ensuring each returns success if required, and returns a `Ethers.TxData` struct,\nwhich can be passed to `Ethers.call/2`.\n\nFor more details, refer to: https://github.com/mds1/multicall#batch-contract-reads","title":"Ethers.Multicall.aggregate3/1","ref":"Ethers.Multicall.html#aggregate3/1"},{"type":"function","doc":"- `data`: A list of `Ethers.TxData` structs or `{%Ethers.TxData{...}, options}` tuples. The options\ncan include:\n  - `allow_failure`: If set to `false`, the execution will revert. Defaults to `true`.\n  - `to`: Overrides the `default_address` (if any) for the respective function call.","title":"Parameters - Ethers.Multicall.aggregate3/1","ref":"Ethers.Multicall.html#aggregate3/1-parameters"},{"type":"function","doc":"```elixir\nEthers.Multicall.aggregate3([\n  ContractA.foo(), # <-- Assumes `default_address` in ContractA is defined.\n  { ContractB.bar(), to: \"0x...\" }, # <-- ContractB.bar() will call `to`.\n  { ContractC.baz(), allow_failure: false, to: \"0x...\" }\n  # ^^^ -> ContractC.baz() will call `to` and will revert on failure.\n  { ContractD.foo(), allow_failure: false } # <-- ContractD.foo() will revert on failure.\n])\n#Ethers.TxData \n```","title":"Examples - Ethers.Multicall.aggregate3/1","ref":"Ethers.Multicall.html#aggregate3/1-examples"},{"type":"function","doc":"Decodes an `aggregate3/2` response from `Ethers.call/2`.","title":"Ethers.Multicall.aggregate3_decode/2","ref":"Ethers.Multicall.html#aggregate3_decode/2"},{"type":"function","doc":"- resps: The response from `Ethers.call/2`.\n- calls: A list of the function calls or signatures passed to `aggregate3/2`.","title":"Parameters - Ethers.Multicall.aggregate3_decode/2","ref":"Ethers.Multicall.html#aggregate3_decode/2-parameters"},{"type":"function","doc":"```elixir\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls\n|> Ethers.Multicall.aggregate3()\n|> Ethers.call!()\n|> Ethers.Multicall.aggregate3_decode(calls)\n[ true: \"bar\", true: \"baz\" ]\n```","title":"Examples - Ethers.Multicall.aggregate3_decode/2","ref":"Ethers.Multicall.html#aggregate3_decode/2-examples"},{"type":"function","doc":"Encodes a function call with optional options into a multicall3 compatible (address,bool,bytes)\ntuple.","title":"Ethers.Multicall.aggregate3_encode_data/1","ref":"Ethers.Multicall.html#aggregate3_encode_data/1"},{"type":"function","doc":"- data: A `Ethers.TxData` struct or `{%Ethers.TxData{...}, options}`. The options can include:\n  - allow_failure: If false the execution will revert. Defaults to true.\n  - to: Overrides the `default_address` (if any) for the respective function call.","title":"Parameters - Ethers.Multicall.aggregate3_encode_data/1","ref":"Ethers.Multicall.html#aggregate3_encode_data/1-parameters"},{"type":"function","doc":"```elixir\n{ ContractA.foo(), allow_failure: false } |> aggregate3_encode_data()\n{\"0x...\", false, <<...>>}\n\nContractB.bar() |> aggregate3_encode_data()\n{\"0x...\", true, <<...>>}\n```","title":"Examples - Ethers.Multicall.aggregate3_encode_data/1","ref":"Ethers.Multicall.html#aggregate3_encode_data/1-examples"},{"type":"type","doc":"","title":"Ethers.Multicall.aggregate3_option/0","ref":"Ethers.Multicall.html#t:aggregate3_option/0"},{"type":"function","doc":"Decodes a `Multicall3` response from `Ethers.call/2`.","title":"Ethers.Multicall.decode/2","ref":"Ethers.Multicall.html#decode/2"},{"type":"function","doc":"- resps: List of results returned by aggregate call (The response from `Ethers.call/2`).\n- calls: List of the function calls or signatures passed to `aggregate3/2` or `aggregate2/2`.\n  (used for decoding)","title":"Parameters - Ethers.Multicall.decode/2","ref":"Ethers.Multicall.html#decode/2-parameters"},{"type":"function","doc":"```elixir\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls |> Ethers.Multicall.aggregate3() |> Ethers.call!() |> Ethers.Multicall.decode(calls)\n[ true: \"bar\", true: \"baz\" ]\n\ncalls = [ ContractA.foo(), { ContractB.foo(), to: \"0x...\" } ]\ncalls |> Ethers.Multicall.aggregate2() |> Ethers.call!() |> Ethers.Multicall.decode(calls)\n[ 1337, [ \"bar\", \"baz\" ]]\n```","title":"Examples - Ethers.Multicall.decode/2","ref":"Ethers.Multicall.html#decode/2-examples"},{"type":"module","doc":"Name Service resolution implementation for ENS (Ethereum Name Service).\nSupports both forward and reverse resolution plus reverse lookups.\n\nThis module implements [Cross Chain / Offchain Resolvers](https://docs.ens.domains/resolvers/ccip-read)\n(is CCIP-Read aware), allowing it to resolve names that are stored:\n- On-chain (traditional L1 ENS resolution on Ethereum)\n- Off-chain (via CCIP-Read gateway servers)\n- Cross-chain (on other L2s and EVM-compatible blockchains)\n\nThe resolution process automatically handles these different scenarios transparently,\nfollowing the ENS standards for name resolution including ENSIP-10 and ENSIP-11.","title":"Ethers.NameService","ref":"Ethers.NameService.html"},{"type":"function","doc":"Implementation of namehash function in Elixir.\n\nSee https://docs.ens.domains/contract-api-reference/name-processing","title":"Ethers.NameService.name_hash/1","ref":"Ethers.NameService.html#name_hash/1"},{"type":"function","doc":"iex> Ethers.NameService.name_hash(\"foo.eth\")\n    Ethers.Utils.hex_decode!(\"0xde9b09fd7c5f901e23a3f19fecc54828e9c848539801e86591bd9801b019f84f\")\n\n    iex> Ethers.NameService.name_hash(\"alisina.eth\")\n    Ethers.Utils.hex_decode!(\"0x1b557b3901bef3a986febf001c3b19370b34064b130d49ea967bf150f6d23dfe\")","title":"Examples - Ethers.NameService.name_hash/1","ref":"Ethers.NameService.html#name_hash/1-examples"},{"type":"function","doc":"Resolves a name on blockchain.","title":"Ethers.NameService.resolve/2","ref":"Ethers.NameService.html#resolve/2"},{"type":"function","doc":"- name: Domain name to resolve. (Example: `foo.eth`)\n- opts: Resolve options.\n  - resolve_call: TxData for resolution (Defaults to\n  `Ethers.Contracts.ENS.Resolver.addr(Ethers.NameService.name_hash(name))`)\n  - to: Resolver contract address. Defaults to ENS\n  - Accepts all other Execution options from `Ethers.call/2`.","title":"Parameters - Ethers.NameService.resolve/2","ref":"Ethers.NameService.html#resolve/2-parameters"},{"type":"function","doc":"```elixir\nEthers.NameService.resolve(\"vitalik.eth\")\n{:ok, \"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"}\n```","title":"Examples - Ethers.NameService.resolve/2","ref":"Ethers.NameService.html#resolve/2-examples"},{"type":"function","doc":"Same as `resolve/2` but raises on errors.","title":"Ethers.NameService.resolve!/2","ref":"Ethers.NameService.html#resolve!/2"},{"type":"function","doc":"```elixir\nEthers.NameService.resolve!(\"vitalik.eth\")\n\"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"\n```","title":"Examples - Ethers.NameService.resolve!/2","ref":"Ethers.NameService.html#resolve!/2-examples"},{"type":"function","doc":"Resolves an address to a name on blockchain.","title":"Ethers.NameService.reverse_resolve/2","ref":"Ethers.NameService.html#reverse_resolve/2"},{"type":"function","doc":"- address: Address to resolve.\n- opts: Resolve options.\n  - to: Resolver contract address. Defaults to ENS.\n  - chain_id: Chain ID of the target chain Defaults to `1`.\n  - Accepts all other Execution options from `Ethers.call/2`.","title":"Parameters - Ethers.NameService.reverse_resolve/2","ref":"Ethers.NameService.html#reverse_resolve/2-parameters"},{"type":"function","doc":"```elixir\nEthers.NameService.reverse_resolve(\"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\")\n{:ok, \"vitalik.eth\"}\n```","title":"Examples - Ethers.NameService.reverse_resolve/2","ref":"Ethers.NameService.html#reverse_resolve/2-examples"},{"type":"function","doc":"Same as `reverse_resolve/2` but raises on errors.","title":"Ethers.NameService.reverse_resolve!/2","ref":"Ethers.NameService.html#reverse_resolve!/2"},{"type":"function","doc":"```elixir\nEthers.NameService.reverse_resolve!(\"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\")\n\"vitalik.eth\"\n```","title":"Examples - Ethers.NameService.reverse_resolve!/2","ref":"Ethers.NameService.html#reverse_resolve!/2-examples"},{"type":"module","doc":"Transaction struct to hold information about the ABI selector, encoded data\nand the target `to` address.","title":"Ethers.TxData","ref":"Ethers.TxData.html"},{"type":"function","doc":"ABI decodes a function input/output given a TxData or FunctionSelector","title":"Ethers.TxData.abi_decode/3","ref":"Ethers.TxData.html#abi_decode/3"},{"type":"type","doc":"Holds transaction data, the function selector and the default `to` address.\n\nCan be passed in to `Ethers.call/2` or `Ethers.send_transaction/2` to execute.","title":"Ethers.TxData.t/0","ref":"Ethers.TxData.html#t:t/0"},{"type":"function","doc":"Converts a TxData struct and optional overrides to a map ready for RPC data.","title":"Ethers.TxData.to_map/2","ref":"Ethers.TxData.html#to_map/2"},{"type":"module","doc":"EVM types and compound type definitions","title":"Ethers.Types","ref":"Ethers.Types.html"},{"type":"function","doc":"Returns the default value in the given type if supported.","title":"Ethers.Types.default/1","ref":"Ethers.Types.html#default/1"},{"type":"function","doc":"iex> Ethers.Types.default(:address)\n    \"0x0000000000000000000000000000000000000000\"\n\n    iex> Ethers.Types.default({:int, 32})\n    0\n\n    iex> Ethers.Types.default({:uint, 8})\n    0\n\n    iex> Ethers.Types.default({:int, 128})\n    0\n\n    iex> Ethers.Types.default(:string)\n    \"\"\n\n    iex> Ethers.Types.default(:bytes)\n    \"\"\n\n    iex> Ethers.Types.default({:bytes, 8})\n    <<0, 0, 0, 0, 0, 0, 0, 0>>","title":"Examples - Ethers.Types.default/1","ref":"Ethers.Types.html#default/1-examples"},{"type":"function","doc":"Checks if a given data matches a given solidity type","title":"Ethers.Types.matches_type?/2","ref":"Ethers.Types.html#matches_type?/2"},{"type":"function","doc":"iex> Ethers.Types.matches_type?(false, :bool)\n    true\n\n    iex> Ethers.Types.matches_type?(200, {:uint, 8})\n    true\n\n    iex> Ethers.Types.matches_type?(400, {:uint, 8})\n    false\n\n    iex> Ethers.Types.matches_type?(\"0xdAC17F958D2ee523a2206206994597C13D831ec7\", :address)\n    true","title":"Examples - Ethers.Types.matches_type?/2","ref":"Ethers.Types.html#matches_type?/2-examples"},{"type":"function","doc":"Returns the maximum possible value in the given type if supported.","title":"Ethers.Types.max/1","ref":"Ethers.Types.html#max/1"},{"type":"function","doc":"iex> Ethers.Types.max({:uint, 8})\n    255\n\n    iex> Ethers.Types.max({:int, 8})\n    127\n\n    iex> Ethers.Types.max({:uint, 16})\n    65535\n\n    iex> Ethers.Types.max({:int, 16})\n    32767\n\n    iex> Ethers.Types.max({:uint, 128})\n    340282366920938463463374607431768211455\n\n    iex> Ethers.Types.max({:int, 128})\n    170141183460469231731687303715884105727","title":"Examples - Ethers.Types.max/1","ref":"Ethers.Types.html#max/1-examples"},{"type":"function","doc":"Returns the minimum possible value in the given type if supported.","title":"Ethers.Types.min/1","ref":"Ethers.Types.html#min/1"},{"type":"function","doc":"iex> Ethers.Types.min({:uint, 8})\n    0\n\n    iex> Ethers.Types.min({:int, 8})\n    -128\n\n    iex> Ethers.Types.min({:uint, 16})\n    0\n\n    iex> Ethers.Types.min({:int, 16})\n    -32768\n\n    iex> Ethers.Types.min({:int, 24})\n    -8388608\n\n    iex> Ethers.Types.min({:int, 128})\n    -170141183460469231731687303715884105728","title":"Examples - Ethers.Types.min/1","ref":"Ethers.Types.html#min/1-examples"},{"type":"type","doc":"Ethereum address in its hex format with 0x or in its binary format","title":"Ethers.Types.t_address/0","ref":"Ethers.Types.html#t:t_address/0"},{"type":"type","doc":"- `\"0xdAC17F958D2ee523a2206206994597C13D831ec7\"`\n- `<<218, 193, 127, 149, 141, 46, 229, 35, 162, 32, 98, 6, 153, 69, 151, 193, 61, 131, 30, 199>>`","title":"Examples - Ethers.Types.t_address/0","ref":"Ethers.Types.html#t:t_address/0-examples"},{"type":"type","doc":"","title":"Ethers.Types.t_bitsizes/0","ref":"Ethers.Types.html#t:t_bitsizes/0"},{"type":"type","doc":"","title":"Ethers.Types.t_bytesizes/0","ref":"Ethers.Types.html#t:t_bytesizes/0"},{"type":"type","doc":"","title":"Ethers.Types.t_evm_types/0","ref":"Ethers.Types.html#t:t_evm_types/0"},{"type":"type","doc":"keccak hash in its hex format with 0x","title":"Ethers.Types.t_hash/0","ref":"Ethers.Types.html#t:t_hash/0"},{"type":"type","doc":"- `\"0xd4288c8e733eb71a39fe2e8dd4912ce54d8d26d9874f30309b26b4b071260422\"`","title":"Examples - Ethers.Types.t_hash/0","ref":"Ethers.Types.html#t:t_hash/0-examples"},{"type":"type","doc":"Public key either in its uncompressed format (64 bytes MAY BE prefixed with 0x04) or its\ncompressed format (32 bytes MUST BE prefixed with 0x02 or 0x03)\n\nIt can be hex encoded but only with 0x prefix.\n\nCompressed public key MUST have a prefix.","title":"Ethers.Types.t_pub_key/0","ref":"Ethers.Types.html#t:t_pub_key/0"},{"type":"function","doc":"Converts EVM data types to typespecs for documentation","title":"Ethers.Types.to_elixir_type/1","ref":"Ethers.Types.html#to_elixir_type/1"},{"type":"function","doc":"Validates and creates typed values to use with functions or events.\n\nTyped values are useful when there are multiple overloads of same function or event and you need\nto specify one of them to be used.\n\nAlso raises with ArgumentError in case value does not match the given type.","title":"Ethers.Types.typed/2","ref":"Ethers.Types.html#typed/2"},{"type":"function","doc":"iex> Ethers.Types.typed({:uint, 256}, 5)\n    {:typed, {:uint, 256}, 5}\n\n    iex> Ethers.Types.typed(:bytes, <<0, 1, 2>>)\n    {:typed, :bytes, <<0, 1, 2>>}","title":"Examples - Ethers.Types.typed/2","ref":"Ethers.Types.html#typed/2-examples"},{"type":"module","doc":"Utilities for interacting with ethereum blockchain","title":"Ethers.Utils","ref":"Ethers.Utils.html"},{"type":"function","doc":"Returns the nearest block number to a given date and time.","title":"Ethers.Utils.date_to_block_number/3","ref":"Ethers.Utils.html#date_to_block_number/3"},{"type":"function","doc":"- date_or_date_time: Can be a `Date`, `DateTime` or an integer unix timestamp.\n- ref_block_number: A block number of reference which is closer to the target block.\n  Can make search time faster if given. (Defaults to current block number)\n- opts: Optional extra options.\n  - acceptable_drift: Can be set to override the default acceptable_drift of\n    120 seconds. This value can be reduced for more accurate results.\n  - sample_size: Can be set to override the default sample_size of 5000 blocks.\n  - backoff_timeout: An optional backoff in milliseconds that will happen between RPC calls.\n    (Useful to prevent quote errors)","title":"Parameters - Ethers.Utils.date_to_block_number/3","ref":"Ethers.Utils.html#date_to_block_number/3-parameters"},{"type":"function","doc":"Decode a hex-encoded Ethereum address to its binary form.\nReturns error if the address is invalid (wrong length or invalid hex).","title":"Ethers.Utils.decode_address/1","ref":"Ethers.Utils.html#decode_address/1"},{"type":"function","doc":"iex> Ethers.Utils.decode_address(\"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\")\n    {:ok, <<144, 248, 191, 106, 71, 159, 50, 14, 173, 7, 68, 17, 164, 176, 231, 148, 78, 168, 201, 193>>}\n\n    iex> Ethers.Utils.decode_address(nil)\n    {:error, :invalid_address}\n\n    iex> Ethers.Utils.decode_address(\"0xinvalid\")\n    {:error, :invalid_address}","title":"Examples - Ethers.Utils.decode_address/1","ref":"Ethers.Utils.html#decode_address/1-examples"},{"type":"function","doc":"Same as `decode_address/1` but raises on error.","title":"Ethers.Utils.decode_address!/1","ref":"Ethers.Utils.html#decode_address!/1"},{"type":"function","doc":"iex> Ethers.Utils.decode_address!(\"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\")\n    <<144, 248, 191, 106, 71, 159, 50, 14, 173, 7, 68, 17, 164, 176, 231, 148, 78, 168, 201, 193>>","title":"Examples - Ethers.Utils.decode_address!/1","ref":"Ethers.Utils.html#decode_address!/1-examples"},{"type":"function","doc":"Encode a binary Ethereum address to its hex form.\nReturns error if the address is invalid (wrong length).","title":"Ethers.Utils.encode_address/1","ref":"Ethers.Utils.html#encode_address/1"},{"type":"function","doc":"iex> address = <<144, 248, 191, 106, 71, 159, 50, 14, 173, 7, 68, 17, 164, 176, 231, 148, 78, 168, 201, 193>>\n    iex> Ethers.Utils.encode_address(address)\n    {:ok, \"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\"}\n\n    iex> Ethers.Utils.encode_address(<<1, 2, 3>>)\n    {:error, :invalid_address}","title":"Examples - Ethers.Utils.encode_address/1","ref":"Ethers.Utils.html#encode_address/1-examples"},{"type":"function","doc":"Same as `encode_address/1` but raises on error.","title":"Ethers.Utils.encode_address!/1","ref":"Ethers.Utils.html#encode_address!/1"},{"type":"function","doc":"iex> address = <<144, 248, 191, 106, 71, 159, 50, 14, 173, 7, 68, 17, 164, 176, 231, 148, 78, 168, 201, 193>>\n    iex> Ethers.Utils.encode_address!(address)\n    \"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\"","title":"Examples - Ethers.Utils.encode_address!/1","ref":"Ethers.Utils.html#encode_address!/1-examples"},{"type":"function","doc":"Convert WEI to ETH","title":"Ethers.Utils.from_wei/1","ref":"Ethers.Utils.html#from_wei/1"},{"type":"function","doc":"iex> Ethers.Utils.from_wei(1000000000000000000)\n    1.0\n\n    iex> Ethers.Utils.from_wei(3140000000000000000)\n    3.14\n\n    iex> Ethers.Utils.from_wei(-10000000000000000000)\n    -10.0","title":"Examples - Ethers.Utils.from_wei/1","ref":"Ethers.Utils.html#from_wei/1-examples"},{"type":"function","doc":"Returns the timestamp for a given block number.\n\nThe block_number parameter can be a non negative integer or the hex encoded value of that integer.\n(The hex encoding *must* start with 0x prefix)","title":"Ethers.Utils.get_block_timestamp/2","ref":"Ethers.Utils.html#get_block_timestamp/2"},{"type":"function","doc":"Decode from hex with (or without) 0x prefix.","title":"Ethers.Utils.hex_decode/1","ref":"Ethers.Utils.html#hex_decode/1"},{"type":"function","doc":"iex> Ethers.Utils.hex_decode(\"0x6574686572735f6578\")\n    {:ok, \"ethers_ex\"}\n\n    iex> Ethers.Utils.hex_decode(\"6574686572735f6578\")\n    {:ok, \"ethers_ex\"}\n\n    iex> Ethers.Utils.hex_decode(\"0x686\")\n    {:ok, <<6, 134>>}","title":"Examples - Ethers.Utils.hex_decode/1","ref":"Ethers.Utils.html#hex_decode/1-examples"},{"type":"function","doc":"Same as `hex_decode/1` but raises on error","title":"Ethers.Utils.hex_decode!/1","ref":"Ethers.Utils.html#hex_decode!/1"},{"type":"function","doc":"iex> Ethers.Utils.hex_decode!(\"0x6574686572735f6578\")\n    \"ethers_ex\"\n\n    iex> Ethers.Utils.hex_decode!(\"6574686572735f6578\")\n    \"ethers_ex\"","title":"Examples - Ethers.Utils.hex_decode!/1","ref":"Ethers.Utils.html#hex_decode!/1-examples"},{"type":"function","doc":"Encode to hex with 0x prefix.","title":"Ethers.Utils.hex_encode/2","ref":"Ethers.Utils.html#hex_encode/2"},{"type":"function","doc":"iex> Ethers.Utils.hex_encode(\"ethers_ex\")\n    \"0x6574686572735f6578\"","title":"Examples - Ethers.Utils.hex_encode/2","ref":"Ethers.Utils.html#hex_encode/2-examples"},{"type":"function","doc":"Converts a hexadecimal integer to integer form","title":"Ethers.Utils.hex_to_integer/1","ref":"Ethers.Utils.html#hex_to_integer/1"},{"type":"function","doc":"iex> Ethers.Utils.hex_to_integer(\"0x11111\")\n    {:ok, 69905}","title":"Examples - Ethers.Utils.hex_to_integer/1","ref":"Ethers.Utils.html#hex_to_integer/1-examples"},{"type":"function","doc":"Same as `hex_to_integer/1` but raises on error","title":"Ethers.Utils.hex_to_integer!/1","ref":"Ethers.Utils.html#hex_to_integer!/1"},{"type":"function","doc":"iex> Ethers.Utils.hex_to_integer!(\"0x11111\")\n    69905","title":"Examples - Ethers.Utils.hex_to_integer!/1","ref":"Ethers.Utils.html#hex_to_integer!/1-examples"},{"type":"function","doc":"Reverse of `prepare_arg/2`","title":"Ethers.Utils.human_arg/2","ref":"Ethers.Utils.html#human_arg/2"},{"type":"function","doc":"iex> Ethers.Utils.human_arg(<<192, 42, 170, 57, 178, 35, 254, 141, 10, 14, 92, 79, 39,\n    ...> 234, 217, 8, 60, 117, 108, 194>>, :address)\n    \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\"\n\n    iex> Ethers.Utils.human_arg(\"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\", :address)\n    \"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\"","title":"Examples - Ethers.Utils.human_arg/2","ref":"Ethers.Utils.html#human_arg/2-examples"},{"type":"function","doc":"Converts integer to its hexadecimal form","title":"Ethers.Utils.integer_to_hex/1","ref":"Ethers.Utils.html#integer_to_hex/1"},{"type":"function","doc":"iex> Ethers.Utils.integer_to_hex(69905)\n    \"0x11111\"","title":"Examples - Ethers.Utils.integer_to_hex/1","ref":"Ethers.Utils.html#integer_to_hex/1-examples"},{"type":"function","doc":"Adds gas limit estimation to the parameters if not already exists\n\nIf option `mult` is given, a gas limit multiplied by `mult` divided by 1000 will be used.\nDefault for `mult` is 100. (1%)","title":"Ethers.Utils.maybe_add_gas_limit/2","ref":"Ethers.Utils.html#maybe_add_gas_limit/2"},{"type":"function","doc":"Converts human readable argument to the form required for ABI encoding.\n\nFor example the addresses in Ethereum are represented by hex strings in human readable format\nbut are in 160-bit binaries in ABI form.","title":"Ethers.Utils.prepare_arg/2","ref":"Ethers.Utils.html#prepare_arg/2"},{"type":"function","doc":"iex> Ethers.Utils.prepare_arg(\"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2\", :address)\n    <<192, 42, 170, 57, 178, 35, 254, 141, 10, 14, 92, 79, 39, 234, 217, 8, 60, 117, 108, 194>>","title":"Examples - Ethers.Utils.prepare_arg/2","ref":"Ethers.Utils.html#prepare_arg/2-examples"},{"type":"function","doc":"Calculates address of a given public key. Public key can be in compressed or decompressed format\neither with or without prefix. It can also be hex encoded.","title":"Ethers.Utils.public_key_to_address/2","ref":"Ethers.Utils.html#public_key_to_address/2"},{"type":"function","doc":"iex> Utils.public_key_to_address(\"0x04e68acfc0253a10620dff706b0a1b1f1f5833ea3beb3bde2250d5f271f3563606672ebc45e0b7ea2e816ecb70ca03137b1c9476eec63d4632e990020b7b6fba39\")\n    \"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\"\n\n    iex> Utils.public_key_to_address(\"0x03e68acfc0253a10620dff706b0a1b1f1f5833ea3beb3bde2250d5f271f3563606\")\n    \"0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1\"","title":"Examples - Ethers.Utils.public_key_to_address/2","ref":"Ethers.Utils.html#public_key_to_address/2-examples"},{"type":"function","doc":"Removes leading zeros from a binary.","title":"Ethers.Utils.remove_leading_zeros/1","ref":"Ethers.Utils.html#remove_leading_zeros/1"},{"type":"function","doc":"Will convert an upper or lowercase Ethereum address to a checksum address.\n\nIf `chain_id` is specified, ERC-1191 checksum encoding will be used.\nNOTE: ERC-1191 is generally NOT backwards compatible with ERC-55 encoding\n      (encoding without `chain_id`).","title":"Ethers.Utils.to_checksum_address/2","ref":"Ethers.Utils.html#to_checksum_address/2"},{"type":"function","doc":"iex> Ethers.Utils.to_checksum_address(\"0xc1912fee45d61c87cc5ea59dae31190fffff232d\")\n    \"0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d\"\n\n    iex> Ethers.Utils.to_checksum_address(\"0XC1912FEE45D61C87CC5EA59DAE31190FFFFF232D\")\n    \"0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d\"\n\n    iex> Ethers.Utils.to_checksum_address(\"0xde709f2102306220921060314715629080e2fb77\", 31)\n    \"0xDE709F2102306220921060314715629080e2Fb77\"\n\n    iex> Ethers.Utils.to_checksum_address(\"0XDE709F2102306220921060314715629080e2Fb77\", 30)\n    \"0xDe709F2102306220921060314715629080e2FB77\"","title":"Examples - Ethers.Utils.to_checksum_address/2","ref":"Ethers.Utils.html#to_checksum_address/2-examples"},{"type":"function","doc":"Converts ETH to WEI","title":"Ethers.Utils.to_wei/1","ref":"Ethers.Utils.html#to_wei/1"},{"type":"function","doc":"iex> Ethers.Utils.to_wei(1)\n    1000000000000000000\n\n    iex> Ethers.Utils.to_wei(3.14)\n    3140000000000000000\n\n    iex> Ethers.Utils.to_wei(0)\n    0\n\n    iex> Ethers.Utils.to_wei(-10)\n    -10000000000000000000","title":"Examples - Ethers.Utils.to_wei/1","ref":"Ethers.Utils.html#to_wei/1-examples"},{"type":"function","doc":"Checks the checksum of a given address. Will also return false on non-checksum addresses.","title":"Ethers.Utils.valid_checksum_address?/1","ref":"Ethers.Utils.html#valid_checksum_address?/1"},{"type":"function","doc":"iex> Ethers.Utils.valid_checksum_address?(\"0xc1912fEE45d61C87Cc5EA59DaE31190FFFFf232d\")\n    true\n\n    iex> Ethers.Utils.valid_checksum_address?(\"0xc1912fee45d61C87Cc5EA59DaE31190FFFFf232d\")\n    false","title":"Examples - Ethers.Utils.valid_checksum_address?/1","ref":"Ethers.Utils.html#valid_checksum_address?/1-examples"},{"type":"behaviour","doc":"Transaction struct and helper functions for handling EVM transactions.\n\nThis module provides functionality to:\n- Create and manipulate transaction structs\n- Encode transactions for network transmission\n- Handle different transaction types (legacy, EIP-1559, etc.)","title":"Ethers.Transaction","ref":"Ethers.Transaction.html"},{"type":"function","doc":"Fills missing transaction fields with default values from the network based on transaction type.","title":"Ethers.Transaction.add_auto_fetchable_fields/2","ref":"Ethers.Transaction.html#add_auto_fetchable_fields/2"},{"type":"function","doc":"- `params` - Updated Transaction params\n  - `opts` - Options to pass to the RPC client","title":"Parameters - Ethers.Transaction.add_auto_fetchable_fields/2","ref":"Ethers.Transaction.html#add_auto_fetchable_fields/2-parameters"},{"type":"function","doc":"- `{:ok, params}` - Filled transaction struct\n  - `{:error, reason}` - If fetching defaults fails","title":"Returns - Ethers.Transaction.add_auto_fetchable_fields/2","ref":"Ethers.Transaction.html#add_auto_fetchable_fields/2-returns"},{"type":"callback","doc":"Returns a list of fields that can be auto-fetched from the network.","title":"Ethers.Transaction.auto_fetchable_fields/0","ref":"Ethers.Transaction.html#c:auto_fetchable_fields/0"},{"type":"function","doc":"Decodes a raw transaction from a binary or hex-encoded string.\n\nTransaction strings must be prefixed with \"0x\" for hex-encoded inputs.\nHandles both legacy and typed transactions (EIP-1559, etc).","title":"Ethers.Transaction.decode/1","ref":"Ethers.Transaction.html#decode/1"},{"type":"function","doc":"- `raw_transaction` - Raw transaction data as a binary or hex string starting with \"0x\"","title":"Parameters - Ethers.Transaction.decode/1","ref":"Ethers.Transaction.html#decode/1-parameters"},{"type":"function","doc":"- `{:ok, transaction}` - Decoded transaction struct\n  - `{:error, reason}` - Error decoding transaction","title":"Returns - Ethers.Transaction.decode/1","ref":"Ethers.Transaction.html#decode/1-returns"},{"type":"function","doc":"Encodes a transaction for network transmission following EIP-155/EIP-1559.\n\nHandles both legacy and EIP-1559 transaction types, including signature data if present.","title":"Ethers.Transaction.encode/1","ref":"Ethers.Transaction.html#encode/1"},{"type":"function","doc":"- `transaction` - Transaction struct to encode","title":"Parameters - Ethers.Transaction.encode/1","ref":"Ethers.Transaction.html#encode/1-parameters"},{"type":"function","doc":"- `binary` - RLP encoded transaction with appropriate type envelope","title":"Returns - Ethers.Transaction.encode/1","ref":"Ethers.Transaction.html#encode/1-returns"},{"type":"callback","doc":"Constructs a transaction from a decoded RLP list","title":"Ethers.Transaction.from_rlp_list/1","ref":"Ethers.Transaction.html#c:from_rlp_list/1"},{"type":"function","doc":"Converts a map (typically from JSON-RPC response) into a Transaction struct.\n\nHandles different field naming conventions and transaction types.","title":"Ethers.Transaction.from_rpc_map/1","ref":"Ethers.Transaction.html#from_rpc_map/1"},{"type":"function","doc":"- `tx` - Map containing transaction data. Keys can be snakeCase strings or atoms.\n  (e.g `:chainId`, `\"gasPrice\"`)","title":"Parameters - Ethers.Transaction.from_rpc_map/1","ref":"Ethers.Transaction.html#from_rpc_map/1-parameters"},{"type":"function","doc":"- `{:ok, transaction}` - Converted transaction struct\n  - `{:error, :unsupported_type}` - If transaction type is not supported","title":"Returns - Ethers.Transaction.from_rpc_map/1","ref":"Ethers.Transaction.html#from_rpc_map/1-returns"},{"type":"function","doc":"Creates a new transaction struct with the given parameters.\n\nType of transaction is determined by the `type` field in the params map or defaults to EIP-1559.","title":"Ethers.Transaction.new/1","ref":"Ethers.Transaction.html#new/1"},{"type":"function","doc":"iex> Ethers.Transaction.new(%{type: Ethers.Transaction.Eip1559, from: \"0x123...\", to: \"0x456...\", value: \"0x0\"})\n    {:ok, %Ethers.Transaction.Eip1559{from: \"0x123...\", to: \"0x456...\", value: \"0x0\"}}","title":"Examples - Ethers.Transaction.new/1","ref":"Ethers.Transaction.html#new/1-examples"},{"type":"callback","doc":"Creates a new transaction struct with the given parameters.","title":"Ethers.Transaction.new/1","ref":"Ethers.Transaction.html#c:new/1"},{"type":"type","doc":"EVM Transaction type","title":"Ethers.Transaction.t/0","ref":"Ethers.Transaction.html#t:t/0"},{"type":"type","doc":"EVM Transaction payload type","title":"Ethers.Transaction.t_payload/0","ref":"Ethers.Transaction.html#t:t_payload/0"},{"type":"function","doc":"Converts a Transaction struct into a map suitable for JSON-RPC.","title":"Ethers.Transaction.to_rpc_map/1","ref":"Ethers.Transaction.html#to_rpc_map/1"},{"type":"function","doc":"- `transaction` - Transaction struct to convert","title":"Parameters - Ethers.Transaction.to_rpc_map/1","ref":"Ethers.Transaction.html#to_rpc_map/1-parameters"},{"type":"function","doc":"- map containing transaction parameters with RPC field names and \"0x\" prefixed hex values","title":"Returns - Ethers.Transaction.to_rpc_map/1","ref":"Ethers.Transaction.html#to_rpc_map/1-returns"},{"type":"function","doc":"Calculates the transaction hash.","title":"Ethers.Transaction.transaction_hash/2","ref":"Ethers.Transaction.html#transaction_hash/2"},{"type":"function","doc":"- `transaction` - Transaction struct to hash\n- `format` - Format to return the hash in. Either `:hex` or `:bin`. (default: `:hex`)","title":"Parameters - Ethers.Transaction.transaction_hash/2","ref":"Ethers.Transaction.html#transaction_hash/2-parameters"},{"type":"function","doc":"- `binary` - Transaction hash in binary format (when `format` is `:bin`)\n- `String.t()` - Transaction hash in hex format prefixed with \"0x\" (when `format` is `:hex`)","title":"Returns Either - Ethers.Transaction.transaction_hash/2","ref":"Ethers.Transaction.html#transaction_hash/2-returns-either"},{"type":"callback","doc":"Returns the type envelope for the transaction.","title":"Ethers.Transaction.type_envelope/0","ref":"Ethers.Transaction.html#c:type_envelope/0"},{"type":"callback","doc":"Returns the type ID for the transaction. e.g Legacy: 0, EIP-1559: 2","title":"Ethers.Transaction.type_id/0","ref":"Ethers.Transaction.html#c:type_id/0"},{"type":"module","doc":"Transaction struct and protocol implementation for Ethereum Improvement Proposal (EIP) 1559\ntransactions. EIP-1559 introduced a new fee market mechanism with base fee and priority fee.\n\nSee: https://eips.ethereum.org/EIPS/eip-1559","title":"Ethers.Transaction.Eip1559","ref":"Ethers.Transaction.Eip1559.html"},{"type":"type","doc":"A transaction type following EIP-1559 (Type-2) and incorporating the following fields:\n- `chain_id` - chain ID of network where the transaction is to be executed\n- `nonce` - sequence number for the transaction from this sender\n- `max_priority_fee_per_gas` - maximum fee per gas (in wei) to give to validators as priority fee (introduced in EIP-1559)\n- `max_fee_per_gas` - maximum total fee per gas (in wei) willing to pay (introduced in EIP-1559)\n- `gas` - maximum amount of gas allowed for transaction execution\n- `to` - destination address for transaction, nil for contract creation\n- `value` - amount of ether (in wei) to transfer\n- `input` - data payload of the transaction\n- `access_list` - list of addresses and storage keys to warm up (introduced in EIP-2930)","title":"Ethers.Transaction.Eip1559.t/0","ref":"Ethers.Transaction.Eip1559.html#t:t/0"},{"type":"module","doc":"Transaction struct and protocol implementation for Ethereum Improvement Proposal (EIP) 2930\ntransactions. EIP-2930 introduced a new transaction type that includes an access list,\nallowing transactions to pre-specify and pre-pay for account and storage access to mitigate\ngas cost changes from EIP-2929 and prevent contract breakage. The access list format also\nenables future use cases like block-wide witnesses and static state access patterns.\n\nSee: https://eips.ethereum.org/EIPS/eip-2930","title":"Ethers.Transaction.Eip2930","ref":"Ethers.Transaction.Eip2930.html"},{"type":"type","doc":"A transaction type following EIP-2930 (Type-1) and incorporating the following fields:\n- `chain_id` - chain ID of network where the transaction is to be executed\n- `nonce` - sequence number for the transaction from this sender\n- `gas_price`: Price willing to pay for each unit of gas (in wei)\n- `gas` - maximum amount of gas allowed for transaction execution\n- `to` - destination address for transaction, nil for contract creation\n- `value` - amount of ether (in wei) to transfer\n- `input` - data payload of the transaction\n- `access_list` - list of addresses and storage keys to warm up (introduced in EIP-2930)","title":"Ethers.Transaction.Eip2930.t/0","ref":"Ethers.Transaction.Eip2930.html#t:t/0"},{"type":"module","doc":"Transaction struct and protocol implementation for Ethereum Improvement Proposal (EIP) 4844\ntransactions. EIP-4844 introduced \"blob-carrying transactions\" which contain a large amount\nof data that cannot be accessed by EVM execution, but whose commitment can be accessed.\n\nSee: https://eips.ethereum.org/EIPS/eip-4844","title":"Ethers.Transaction.Eip4844","ref":"Ethers.Transaction.Eip4844.html"},{"type":"type","doc":"A transaction type following EIP-4844 (Type-3) and incorporating the following fields:\n- `chain_id` - chain ID of network where the transaction is to be executed\n- `nonce` - sequence number for the transaction from this sender\n- `max_priority_fee_per_gas` - maximum fee per gas (in wei) to give to validators as priority fee (introduced in EIP-1559)\n- `max_fee_per_gas` - maximum total fee per gas (in wei) willing to pay (introduced in EIP-1559)\n- `gas` - maximum amount of gas allowed for transaction execution\n- `to` - destination address for transaction, nil for contract creation\n- `value` - amount of ether (in wei) to transfer\n- `input` - data payload of the transaction\n- `access_list` - list of addresses and storage keys to warm up (introduced in EIP-2930)\n- `max_fee_per_blob_gas` - maximum fee per blob gas (in wei) willing to pay (introduced in EIP-4844)\n- `blob_versioned_hashes` - list of versioned hashes of the blobs (introduced in EIP-4844)","title":"Ethers.Transaction.Eip4844.t/0","ref":"Ethers.Transaction.Eip4844.html#t:t/0"},{"type":"module","doc":"Legacy transaction struct and implementation of Transaction.Protocol.","title":"Ethers.Transaction.Legacy","ref":"Ethers.Transaction.Legacy.html"},{"type":"type","doc":"Legacy transaction type (Type-0) incorporating the following fields:\n- nonce: Transaction sequence number for the sending account\n- gas_price: Price willing to pay for each unit of gas (in wei)\n- gas: Maximum number of gas units willing to pay for\n- to: Recipient address or nil for contract creation\n- value: Amount of ether to transfer in wei\n- input: Transaction data payload, also called 'data'\n- chain_id: Network ID from [EIP-155](https://eips.ethereum.org/EIPS/eip-155), defaults to nil for legacy","title":"Ethers.Transaction.Legacy.t/0","ref":"Ethers.Transaction.Legacy.html#t:t/0"},{"type":"module","doc":"Metadata for a transaction like block hash, block number, and transaction index.","title":"Ethers.Transaction.Metadata","ref":"Ethers.Transaction.Metadata.html"},{"type":"type","doc":"Transaction metadata type incorporating the following fields:\n- `block_hash` - hash of the block where the transaction was included\n- `block_number` - block number where the transaction was included\n- `transaction_index` - index of the transaction in the block","title":"Ethers.Transaction.Metadata.t/0","ref":"Ethers.Transaction.Metadata.html#t:t/0"},{"type":"protocol","doc":"Protocol for handling Ethereum Virtual Machine (EVM) transactions.","title":"Ethers.Transaction.Protocol","ref":"Ethers.Transaction.Protocol.html"},{"type":"type","doc":"All the types that implement this protocol.","title":"Ethers.Transaction.Protocol.t/0","ref":"Ethers.Transaction.Protocol.html#t:t/0"},{"type":"function","doc":"Returns a list ready to be RLP encoded for a given transaction.","title":"Ethers.Transaction.Protocol.to_rlp_list/2","ref":"Ethers.Transaction.Protocol.html#to_rlp_list/2"},{"type":"function","doc":"- `transaction` - Transaction struct containing the transaction data\n- `mode` - Encoding mode:\n  - `:payload` - For encoding the transaction payload\n  - `:hash` - For encoding the transaction hash","title":"Parameters - Ethers.Transaction.Protocol.to_rlp_list/2","ref":"Ethers.Transaction.Protocol.html#to_rlp_list/2-parameters"},{"type":"function","doc":"Returns the binary value of the transaction type envelope.\nFor legacy transactions, returns an empty binary.","title":"Ethers.Transaction.Protocol.type_envelope/1","ref":"Ethers.Transaction.Protocol.html#type_envelope/1"},{"type":"function","doc":"Returns type of transaction as an integer.","title":"Ethers.Transaction.Protocol.type_id/1","ref":"Ethers.Transaction.Protocol.html#type_id/1"},{"type":"module","doc":"A struct that wraps a transaction and its signature values.","title":"Ethers.Transaction.Signed","ref":"Ethers.Transaction.Signed.html"},{"type":"function","doc":"Calculates the y-parity or v value for transaction signatures.\n\nHandles both legacy and EIP-1559 transaction types according to their specifications.","title":"Ethers.Transaction.Signed.calculate_y_parity_or_v/2","ref":"Ethers.Transaction.Signed.html#calculate_y_parity_or_v/2"},{"type":"function","doc":"- `tx` - Transaction struct\n  - `recovery_id` - Recovery ID from the signature","title":"Parameters - Ethers.Transaction.Signed.calculate_y_parity_or_v/2","ref":"Ethers.Transaction.Signed.html#calculate_y_parity_or_v/2-parameters"},{"type":"function","doc":"- `integer` - Calculated y-parity or v value","title":"Returns - Ethers.Transaction.Signed.calculate_y_parity_or_v/2","ref":"Ethers.Transaction.Signed.html#calculate_y_parity_or_v/2-returns"},{"type":"function","doc":"Calculates the from address of a signed transaction using its signature.\n\nThe from address is inferred from the signature of the transaction rather than being explicitly\nspecified. This is done by recovering the signer's public key from the signature and then\nderiving the corresponding Ethereum address.","title":"Ethers.Transaction.Signed.from_address/1","ref":"Ethers.Transaction.Signed.html#from_address/1"},{"type":"function","doc":"- `{:ok, address}` - Successfully recovered from address\n  - `{:error, reason}` - Failed to recover address","title":"Returns - Ethers.Transaction.Signed.from_address/1","ref":"Ethers.Transaction.Signed.html#from_address/1-returns"},{"type":"type","doc":"A transaction signature envelope that wraps transaction data with its signature components.\n\nThis type supports both Legacy (pre-EIP-155), EIP-155 Legacy, and EIP-1559 transaction formats.\nThe signature components consist of:\n- `signature_r`, `signature_s`: The ECDSA signature values as defined in Ethereum's Yellow Paper\n- `signature_y_parity_or_v`: The recovery value that varies by transaction type:\n  - For pre-EIP-155 Legacy transactions: v = recovery_id + 27\n  - For EIP-155 Legacy transactions: v = recovery_id + chain_id * 2 + 35\n  - For EIP-1559 transactions: Just the recovery_id (0 or 1) as specified in EIP-2930\n\nRelated EIPs:\n- [EIP-155](https://eips.ethereum.org/EIPS/eip-155): Simple replay attack protection\n- [EIP-1559](https://eips.ethereum.org/EIPS/eip-1559): Fee market change for ETH 1.0 chain\n- [EIP-2930](https://eips.ethereum.org/EIPS/eip-2930): Optional access lists","title":"Ethers.Transaction.Signed.t/0","ref":"Ethers.Transaction.Signed.html#t:t/0"},{"type":"module","doc":"CCIP Read ([EIP-3668](https://eips.ethereum.org/EIPS/eip-3668)) contract","title":"Ethers.Contracts.CcipRead","ref":"Ethers.Contracts.CcipRead.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.CcipRead.__default_address__/0","ref":"Ethers.Contracts.CcipRead.html#__default_address__/0"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.CcipRead.constructor/0","ref":"Ethers.Contracts.CcipRead.html#constructor/0"},{"type":"function","doc":"","title":"Parameters - Ethers.Contracts.CcipRead.constructor/0","ref":"Ethers.Contracts.CcipRead.html#constructor/0-parameters"},{"type":"module","doc":"Ethereum Name Service (ENS) Contract","title":"Ethers.Contracts.ENS","ref":"Ethers.Contracts.ENS.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ENS.__default_address__/0","ref":"Ethers.Contracts.ENS.html#__default_address__/0"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.ENS.constructor/1","ref":"Ethers.Contracts.ENS.html#constructor/1"},{"type":"function","doc":"- _old: `:address`","title":"Parameters - Ethers.Contracts.ENS.constructor/1","ref":"Ethers.Contracts.ENS.html#constructor/1-parameters"},{"type":"function","doc":"Prepares `isApprovedForAll(address owner, address operator)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.is_approved_for_all/2","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/2"},{"type":"function","doc":"- owner: `:address`\n - operator: `:address`","title":"Function Parameter Types - Ethers.Contracts.ENS.is_approved_for_all/2","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.is_approved_for_all/2","ref":"Ethers.Contracts.ENS.html#is_approved_for_all/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `old()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.old/0","ref":"Ethers.Contracts.ENS.html#old/0"},{"type":"function","doc":"- `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.old/0","ref":"Ethers.Contracts.ENS.html#old/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `owner(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.owner/1","ref":"Ethers.Contracts.ENS.html#owner/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.owner/1","ref":"Ethers.Contracts.ENS.html#owner/1-function-parameter-types"},{"type":"function","doc":"- `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.owner/1","ref":"Ethers.Contracts.ENS.html#owner/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `recordExists(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.record_exists/1","ref":"Ethers.Contracts.ENS.html#record_exists/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.record_exists/1","ref":"Ethers.Contracts.ENS.html#record_exists/1-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.record_exists/1","ref":"Ethers.Contracts.ENS.html#record_exists/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `resolver(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.resolver/1","ref":"Ethers.Contracts.ENS.html#resolver/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.resolver/1","ref":"Ethers.Contracts.ENS.html#resolver/1-function-parameter-types"},{"type":"function","doc":"- `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.resolver/1","ref":"Ethers.Contracts.ENS.html#resolver/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setApprovalForAll(address operator, bool approved)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.set_approval_for_all/2","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/2"},{"type":"function","doc":"- operator: `:address`\n - approved: `:bool`","title":"Function Parameter Types - Ethers.Contracts.ENS.set_approval_for_all/2","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_approval_for_all/2","ref":"Ethers.Contracts.ENS.html#set_approval_for_all/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setOwner(bytes32 node, address owner)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.set_owner/2","ref":"Ethers.Contracts.ENS.html#set_owner/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - owner: `:address`","title":"Function Parameter Types - Ethers.Contracts.ENS.set_owner/2","ref":"Ethers.Contracts.ENS.html#set_owner/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_owner/2","ref":"Ethers.Contracts.ENS.html#set_owner/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setRecord(bytes32 node, address owner, address resolver, uint64 ttl)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.set_record/4","ref":"Ethers.Contracts.ENS.html#set_record/4"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n - resolver: `:address`\n - ttl: `{:uint, 64}`","title":"Function Parameter Types - Ethers.Contracts.ENS.set_record/4","ref":"Ethers.Contracts.ENS.html#set_record/4-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_record/4","ref":"Ethers.Contracts.ENS.html#set_record/4-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setResolver(bytes32 node, address resolver)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.set_resolver/2","ref":"Ethers.Contracts.ENS.html#set_resolver/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - resolver: `:address`","title":"Function Parameter Types - Ethers.Contracts.ENS.set_resolver/2","ref":"Ethers.Contracts.ENS.html#set_resolver/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_resolver/2","ref":"Ethers.Contracts.ENS.html#set_resolver/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setSubnodeOwner(bytes32 node, bytes32 label, address owner)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.set_subnode_owner/3","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n - owner: `:address`","title":"Function Parameter Types - Ethers.Contracts.ENS.set_subnode_owner/3","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/3-function-parameter-types"},{"type":"function","doc":"- `{:bytes, 32}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_subnode_owner/3","ref":"Ethers.Contracts.ENS.html#set_subnode_owner/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setSubnodeRecord(bytes32 node, bytes32 label, address owner, address resolver, uint64 ttl)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.set_subnode_record/5","ref":"Ethers.Contracts.ENS.html#set_subnode_record/5"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`\n - owner: `:address`\n - resolver: `:address`\n - ttl: `{:uint, 64}`","title":"Function Parameter Types - Ethers.Contracts.ENS.set_subnode_record/5","ref":"Ethers.Contracts.ENS.html#set_subnode_record/5-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_subnode_record/5","ref":"Ethers.Contracts.ENS.html#set_subnode_record/5-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setTTL(bytes32 node, uint64 ttl)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.set_ttl/2","ref":"Ethers.Contracts.ENS.html#set_ttl/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - ttl: `{:uint, 64}`","title":"Function Parameter Types - Ethers.Contracts.ENS.set_ttl/2","ref":"Ethers.Contracts.ENS.html#set_ttl/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.set_ttl/2","ref":"Ethers.Contracts.ENS.html#set_ttl/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `ttl(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.ttl/1","ref":"Ethers.Contracts.ENS.html#ttl/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.ttl/1","ref":"Ethers.Contracts.ENS.html#ttl/1-function-parameter-types"},{"type":"function","doc":"- `{:uint, 64}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.ttl/1","ref":"Ethers.Contracts.ENS.html#ttl/1-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"Extended ENS resolver as per [ENSIP-10](https://docs.ens.domains/ensip/10)","title":"Ethers.Contracts.ENS.ExtendedResolver","ref":"Ethers.Contracts.ENS.ExtendedResolver.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ENS.ExtendedResolver.__default_address__/0","ref":"Ethers.Contracts.ENS.ExtendedResolver.html#__default_address__/0"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.ENS.ExtendedResolver.constructor/0","ref":"Ethers.Contracts.ENS.ExtendedResolver.html#constructor/0"},{"type":"function","doc":"","title":"Parameters - Ethers.Contracts.ENS.ExtendedResolver.constructor/0","ref":"Ethers.Contracts.ENS.ExtendedResolver.html#constructor/0-parameters"},{"type":"function","doc":"Prepares `resolve(bytes name, bytes data)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.ExtendedResolver.resolve/2","ref":"Ethers.Contracts.ENS.ExtendedResolver.html#resolve/2"},{"type":"function","doc":"- name: `:bytes`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ENS.ExtendedResolver.resolve/2","ref":"Ethers.Contracts.ENS.ExtendedResolver.html#resolve/2-function-parameter-types"},{"type":"function","doc":"- result: `:bytes`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.ExtendedResolver.resolve/2","ref":"Ethers.Contracts.ENS.ExtendedResolver.html#resolve/2-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"Ethereum Name Service (ENS) Resolver Contract","title":"Ethers.Contracts.ENS.Resolver","ref":"Ethers.Contracts.ENS.Resolver.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ENS.Resolver.__default_address__/0","ref":"Ethers.Contracts.ENS.Resolver.html#__default_address__/0"},{"type":"function","doc":"Prepares `ABI(bytes32 node, uint256 contentTypes)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.abi/2","ref":"Ethers.Contracts.ENS.Resolver.html#abi/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - contentTypes: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.abi/2","ref":"Ethers.Contracts.ENS.Resolver.html#abi/2-function-parameter-types"},{"type":"function","doc":"- `{:uint, 256}`\n - `:bytes`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.abi/2","ref":"Ethers.Contracts.ENS.Resolver.html#abi/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `addr(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.addr/1","ref":"Ethers.Contracts.ENS.Resolver.html#addr/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.addr/1","ref":"Ethers.Contracts.ENS.Resolver.html#addr/1-function-parameter-types"},{"type":"function","doc":"- `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.addr/1","ref":"Ethers.Contracts.ENS.Resolver.html#addr/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `addr(bytes32 node, uint256 coinType)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.addr/2","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - coinType: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.addr/2","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2-function-parameter-types"},{"type":"function","doc":"- `:bytes`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.addr/2","ref":"Ethers.Contracts.ENS.Resolver.html#addr/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `authorisations(bytes32, address, address)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.authorisations/3","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/3"},{"type":"function","doc":"- `{:bytes, 32}`\n - `:address`\n - `:address`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.authorisations/3","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/3-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.authorisations/3","ref":"Ethers.Contracts.ENS.Resolver.html#authorisations/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `clearDNSZone(bytes32 node)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.clear_dns_zone/1","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.clear_dns_zone/1","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/1-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.clear_dns_zone/1","ref":"Ethers.Contracts.ENS.Resolver.html#clear_dns_zone/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.ENS.Resolver.constructor/1","ref":"Ethers.Contracts.ENS.Resolver.html#constructor/1"},{"type":"function","doc":"- _ens: `:address`","title":"Parameters - Ethers.Contracts.ENS.Resolver.constructor/1","ref":"Ethers.Contracts.ENS.Resolver.html#constructor/1-parameters"},{"type":"function","doc":"Prepares `contenthash(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.contenthash/1","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.contenthash/1","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/1-function-parameter-types"},{"type":"function","doc":"- `:bytes`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.contenthash/1","ref":"Ethers.Contracts.ENS.Resolver.html#contenthash/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `dnsRecord(bytes32 node, bytes32 name, uint16 resource)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.dns_record/3","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - name: `{:bytes, 32}`\n - resource: `{:uint, 16}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.dns_record/3","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/3-function-parameter-types"},{"type":"function","doc":"- `:bytes`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.dns_record/3","ref":"Ethers.Contracts.ENS.Resolver.html#dns_record/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `hasDNSRecords(bytes32 node, bytes32 name)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.has_dns_records/2","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - name: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.has_dns_records/2","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.has_dns_records/2","ref":"Ethers.Contracts.ENS.Resolver.html#has_dns_records/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `interfaceImplementer(bytes32 node, bytes4 interfaceID)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.interface_implementer/2","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.interface_implementer/2","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/2-function-parameter-types"},{"type":"function","doc":"- `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.interface_implementer/2","ref":"Ethers.Contracts.ENS.Resolver.html#interface_implementer/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `multicall(bytes[] data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.multicall/1","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/1"},{"type":"function","doc":"- data: `{:array, :bytes}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.multicall/1","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/1-function-parameter-types"},{"type":"function","doc":"- results: `{:array, :bytes}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.multicall/1","ref":"Ethers.Contracts.ENS.Resolver.html#multicall/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `name(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.name/1","ref":"Ethers.Contracts.ENS.Resolver.html#name/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.name/1","ref":"Ethers.Contracts.ENS.Resolver.html#name/1-function-parameter-types"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.name/1","ref":"Ethers.Contracts.ENS.Resolver.html#name/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `pubkey(bytes32 node)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.pubkey/1","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.pubkey/1","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/1-function-parameter-types"},{"type":"function","doc":"- x: `{:bytes, 32}`\n - y: `{:bytes, 32}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.pubkey/1","ref":"Ethers.Contracts.ENS.Resolver.html#pubkey/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setABI(bytes32 node, uint256 contentType, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_abi/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - contentType: `{:uint, 256}`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_abi/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_abi/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_abi/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setAddr(bytes32 node, address a)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_addr/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - a: `:address`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_addr/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_addr/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setAddr(bytes32 node, uint256 coinType, bytes a)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_addr/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - coinType: `{:uint, 256}`\n - a: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_addr/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_addr/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_addr/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setAuthorisation(bytes32 node, address target, bool isAuthorised)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_authorisation/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - target: `:address`\n - isAuthorised: `:bool`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_authorisation/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_authorisation/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_authorisation/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setContenthash(bytes32 node, bytes hash)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_contenthash/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - hash: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_contenthash/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_contenthash/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_contenthash/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setDNSRecords(bytes32 node, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_dns_records/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_dns_records/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_dns_records/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_dns_records/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setInterface(bytes32 node, bytes4 interfaceID, address implementer)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_interface/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`\n - implementer: `:address`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_interface/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_interface/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_interface/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setName(bytes32 node, string name)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_name/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - name: `:string`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_name/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_name/2","ref":"Ethers.Contracts.ENS.Resolver.html#set_name/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setPubkey(bytes32 node, bytes32 x, bytes32 y)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_pubkey/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - x: `{:bytes, 32}`\n - y: `{:bytes, 32}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_pubkey/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_pubkey/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_pubkey/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setText(bytes32 node, string key, string value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ENS.Resolver.set_text/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - key: `:string`\n - value: `:string`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.set_text/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.set_text/3","ref":"Ethers.Contracts.ENS.Resolver.html#set_text/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `supportsInterface(bytes4 interfaceID)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `pure`","title":"Ethers.Contracts.ENS.Resolver.supports_interface/1","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/1"},{"type":"function","doc":"- interfaceID: `{:bytes, 4}`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.supports_interface/1","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/1-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.supports_interface/1","ref":"Ethers.Contracts.ENS.Resolver.html#supports_interface/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `text(bytes32 node, string key)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ENS.Resolver.text/2","ref":"Ethers.Contracts.ENS.Resolver.html#text/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - key: `:string`","title":"Function Parameter Types - Ethers.Contracts.ENS.Resolver.text/2","ref":"Ethers.Contracts.ENS.Resolver.html#text/2-function-parameter-types"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ENS.Resolver.text/2","ref":"Ethers.Contracts.ENS.Resolver.html#text/2-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"ERC1155 token interface\n\nMore info: https://eips.ethereum.org/EIPS/eip-1155","title":"Ethers.Contracts.ERC1155","ref":"Ethers.Contracts.ERC1155.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ERC1155.__default_address__/0","ref":"Ethers.Contracts.ERC1155.html#__default_address__/0"},{"type":"function","doc":"Prepares `balanceOf(address account, uint256 id)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC1155.balance_of/2","ref":"Ethers.Contracts.ERC1155.html#balance_of/2"},{"type":"function","doc":"- account: `:address`\n - id: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.balance_of/2","ref":"Ethers.Contracts.ERC1155.html#balance_of/2-function-parameter-types"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.balance_of/2","ref":"Ethers.Contracts.ERC1155.html#balance_of/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `balanceOfBatch(address[] accounts, uint256[] ids)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC1155.balance_of_batch/2","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/2"},{"type":"function","doc":"- accounts: `{:array, :address}`\n - ids: `{:array, {:uint, 256}}`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.balance_of_batch/2","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/2-function-parameter-types"},{"type":"function","doc":"- `{:array, {:uint, 256}}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.balance_of_batch/2","ref":"Ethers.Contracts.ERC1155.html#balance_of_batch/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.ERC1155.constructor/0","ref":"Ethers.Contracts.ERC1155.html#constructor/0"},{"type":"function","doc":"","title":"Parameters - Ethers.Contracts.ERC1155.constructor/0","ref":"Ethers.Contracts.ERC1155.html#constructor/0-parameters"},{"type":"function","doc":"Prepares `isApprovedForAll(address account, address operator)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC1155.is_approved_for_all/2","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/2"},{"type":"function","doc":"- account: `:address`\n - operator: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.is_approved_for_all/2","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.is_approved_for_all/2","ref":"Ethers.Contracts.ERC1155.html#is_approved_for_all/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `safeBatchTransferFrom(address from, address to, uint256[] ids, uint256[] values, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC1155.safe_batch_transfer_from/5","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/5"},{"type":"function","doc":"- from: `:address`\n - to: `:address`\n - ids: `{:array, {:uint, 256}}`\n - values: `{:array, {:uint, 256}}`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.safe_batch_transfer_from/5","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/5-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.safe_batch_transfer_from/5","ref":"Ethers.Contracts.ERC1155.html#safe_batch_transfer_from/5-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `safeTransferFrom(address from, address to, uint256 id, uint256 value, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC1155.safe_transfer_from/5","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/5"},{"type":"function","doc":"- from: `:address`\n - to: `:address`\n - id: `{:uint, 256}`\n - value: `{:uint, 256}`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.safe_transfer_from/5","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/5-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.safe_transfer_from/5","ref":"Ethers.Contracts.ERC1155.html#safe_transfer_from/5-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setApprovalForAll(address operator, bool approved)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC1155.set_approval_for_all/2","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/2"},{"type":"function","doc":"- operator: `:address`\n - approved: `:bool`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.set_approval_for_all/2","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.set_approval_for_all/2","ref":"Ethers.Contracts.ERC1155.html#set_approval_for_all/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `supportsInterface(bytes4 interfaceId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC1155.supports_interface/1","ref":"Ethers.Contracts.ERC1155.html#supports_interface/1"},{"type":"function","doc":"- interfaceId: `{:bytes, 4}`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.supports_interface/1","ref":"Ethers.Contracts.ERC1155.html#supports_interface/1-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.supports_interface/1","ref":"Ethers.Contracts.ERC1155.html#supports_interface/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `uri(uint256)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC1155.uri/1","ref":"Ethers.Contracts.ERC1155.html#uri/1"},{"type":"function","doc":"- `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC1155.uri/1","ref":"Ethers.Contracts.ERC1155.html#uri/1-function-parameter-types"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC1155.uri/1","ref":"Ethers.Contracts.ERC1155.html#uri/1-return-types-when-called-with-ethers-call-2"},{"type":"behaviour","doc":"ERC-165 Standard Interface Detection\n\nMore info: https://eips.ethereum.org/EIPS/eip-165","title":"Ethers.Contracts.ERC165","ref":"Ethers.Contracts.ERC165.html"},{"type":"behaviour","doc":"Contract modules can opt to implement EIP-165 behaviour so that their name can be used\ndirectly with the `supports_interface/1` function in this module. See below example:\n\n```elixir\ndefmodule MyEIP165CompatibleContract do\n  use Ethers.Contract, abi: ...\n  @behaviour Ethers.Contracts.ERC165\n\n  @impl true\n  def erc165_interface_id, do: Ethers.Utils.hex_decode(\"[interface_id]\")\nend\n```\n\nNow module name can be used instead of interface_id and will have the same result.\n\n```elixir\niex> Ethers.Contracts.ERC165.supports_interface(\"[interface_id]\") ==\n  Ethers.Contracts.ERC165.supports_interface(MyEIP165CompatibleContract)\ntrue\n```","title":"Modules as Interface IDs - Ethers.Contracts.ERC165","ref":"Ethers.Contracts.ERC165.html#module-modules-as-interface-ids"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ERC165.__default_address__/0","ref":"Ethers.Contracts.ERC165.html#__default_address__/0"},{"type":"function","doc":"","title":"Ethers.Contracts.ERC165.constructor/0","ref":"Ethers.Contracts.ERC165.html#constructor/0"},{"type":"callback","doc":"","title":"Ethers.Contracts.ERC165.erc165_interface_id/0","ref":"Ethers.Contracts.ERC165.html#c:erc165_interface_id/0"},{"type":"function","doc":"Prepares `supportsInterface(bytes4 interfaceId)` call parameters on the contract.\n\nThis function also accepts a module that implements the ERC165 behaviour as input. Example:\n\n```elixir\niex> Ethers.Contracts.ERC165.supports_interface(Ethers.Contracts.ERC721)\n#Ethers.TxData \n```\n\nThis function should only be called for result and never in a transaction on\nits own. (Use Ethers.call/2)\n\nState mutability: view","title":"Ethers.Contracts.ERC165.supports_interface/1","ref":"Ethers.Contracts.ERC165.html#supports_interface/1"},{"type":"function","doc":"- interfaceId: `{:bytes, 4}`","title":"Function Parameter Types - Ethers.Contracts.ERC165.supports_interface/1","ref":"Ethers.Contracts.ERC165.html#supports_interface/1-function-parameter-types"},{"type":"function","doc":"- :bool","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC165.supports_interface/1","ref":"Ethers.Contracts.ERC165.html#supports_interface/1-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"ERC20 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-20/","title":"Ethers.Contracts.ERC20","ref":"Ethers.Contracts.ERC20.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ERC20.__default_address__/0","ref":"Ethers.Contracts.ERC20.html#__default_address__/0"},{"type":"function","doc":"Prepares `allowance(address owner, address spender)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC20.allowance/2","ref":"Ethers.Contracts.ERC20.html#allowance/2"},{"type":"function","doc":"- owner: `:address`\n - spender: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC20.allowance/2","ref":"Ethers.Contracts.ERC20.html#allowance/2-function-parameter-types"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.allowance/2","ref":"Ethers.Contracts.ERC20.html#allowance/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `approve(address spender, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC20.approve/2","ref":"Ethers.Contracts.ERC20.html#approve/2"},{"type":"function","doc":"- spender: `:address`\n - value: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC20.approve/2","ref":"Ethers.Contracts.ERC20.html#approve/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.approve/2","ref":"Ethers.Contracts.ERC20.html#approve/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `balanceOf(address account)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC20.balance_of/1","ref":"Ethers.Contracts.ERC20.html#balance_of/1"},{"type":"function","doc":"- account: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC20.balance_of/1","ref":"Ethers.Contracts.ERC20.html#balance_of/1-function-parameter-types"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.balance_of/1","ref":"Ethers.Contracts.ERC20.html#balance_of/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.ERC20.constructor/0","ref":"Ethers.Contracts.ERC20.html#constructor/0"},{"type":"function","doc":"","title":"Parameters - Ethers.Contracts.ERC20.constructor/0","ref":"Ethers.Contracts.ERC20.html#constructor/0-parameters"},{"type":"function","doc":"Prepares `decimals()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC20.decimals/0","ref":"Ethers.Contracts.ERC20.html#decimals/0"},{"type":"function","doc":"- `{:uint, 8}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.decimals/0","ref":"Ethers.Contracts.ERC20.html#decimals/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `name()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC20.name/0","ref":"Ethers.Contracts.ERC20.html#name/0"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.name/0","ref":"Ethers.Contracts.ERC20.html#name/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `symbol()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC20.symbol/0","ref":"Ethers.Contracts.ERC20.html#symbol/0"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.symbol/0","ref":"Ethers.Contracts.ERC20.html#symbol/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `totalSupply()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC20.total_supply/0","ref":"Ethers.Contracts.ERC20.html#total_supply/0"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.total_supply/0","ref":"Ethers.Contracts.ERC20.html#total_supply/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `transfer(address to, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC20.transfer/2","ref":"Ethers.Contracts.ERC20.html#transfer/2"},{"type":"function","doc":"- to: `:address`\n - value: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC20.transfer/2","ref":"Ethers.Contracts.ERC20.html#transfer/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.transfer/2","ref":"Ethers.Contracts.ERC20.html#transfer/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `transferFrom(address from, address to, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC20.transfer_from/3","ref":"Ethers.Contracts.ERC20.html#transfer_from/3"},{"type":"function","doc":"- from: `:address`\n - to: `:address`\n - value: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC20.transfer_from/3","ref":"Ethers.Contracts.ERC20.html#transfer_from/3-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC20.transfer_from/3","ref":"Ethers.Contracts.ERC20.html#transfer_from/3-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"ERC721 token interface\n\nMore info: https://eips.ethereum.org/EIPS/eip-721","title":"Ethers.Contracts.ERC721","ref":"Ethers.Contracts.ERC721.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ERC721.__default_address__/0","ref":"Ethers.Contracts.ERC721.html#__default_address__/0"},{"type":"function","doc":"Prepares `approve(address to, uint256 tokenId)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC721.approve/2","ref":"Ethers.Contracts.ERC721.html#approve/2"},{"type":"function","doc":"- to: `:address`\n - tokenId: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC721.approve/2","ref":"Ethers.Contracts.ERC721.html#approve/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.approve/2","ref":"Ethers.Contracts.ERC721.html#approve/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `balanceOf(address owner)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.balance_of/1","ref":"Ethers.Contracts.ERC721.html#balance_of/1"},{"type":"function","doc":"- owner: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC721.balance_of/1","ref":"Ethers.Contracts.ERC721.html#balance_of/1-function-parameter-types"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.balance_of/1","ref":"Ethers.Contracts.ERC721.html#balance_of/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.ERC721.constructor/0","ref":"Ethers.Contracts.ERC721.html#constructor/0"},{"type":"function","doc":"","title":"Parameters - Ethers.Contracts.ERC721.constructor/0","ref":"Ethers.Contracts.ERC721.html#constructor/0-parameters"},{"type":"function","doc":"Prepares `getApproved(uint256 tokenId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.get_approved/1","ref":"Ethers.Contracts.ERC721.html#get_approved/1"},{"type":"function","doc":"- tokenId: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC721.get_approved/1","ref":"Ethers.Contracts.ERC721.html#get_approved/1-function-parameter-types"},{"type":"function","doc":"- `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.get_approved/1","ref":"Ethers.Contracts.ERC721.html#get_approved/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `isApprovedForAll(address owner, address operator)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.is_approved_for_all/2","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/2"},{"type":"function","doc":"- owner: `:address`\n - operator: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC721.is_approved_for_all/2","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.is_approved_for_all/2","ref":"Ethers.Contracts.ERC721.html#is_approved_for_all/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `name()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.name/0","ref":"Ethers.Contracts.ERC721.html#name/0"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.name/0","ref":"Ethers.Contracts.ERC721.html#name/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `ownerOf(uint256 tokenId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.owner_of/1","ref":"Ethers.Contracts.ERC721.html#owner_of/1"},{"type":"function","doc":"- tokenId: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC721.owner_of/1","ref":"Ethers.Contracts.ERC721.html#owner_of/1-function-parameter-types"},{"type":"function","doc":"- `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.owner_of/1","ref":"Ethers.Contracts.ERC721.html#owner_of/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `safeTransferFrom(address from, address to, uint256 tokenId)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC721.safe_transfer_from/3","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/3"},{"type":"function","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC721.safe_transfer_from/3","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.safe_transfer_from/3","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `safeTransferFrom(address from, address to, uint256 tokenId, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC721.safe_transfer_from/4","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4"},{"type":"function","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ERC721.safe_transfer_from/4","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.safe_transfer_from/4","ref":"Ethers.Contracts.ERC721.html#safe_transfer_from/4-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `setApprovalForAll(address operator, bool approved)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC721.set_approval_for_all/2","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/2"},{"type":"function","doc":"- operator: `:address`\n - approved: `:bool`","title":"Function Parameter Types - Ethers.Contracts.ERC721.set_approval_for_all/2","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.set_approval_for_all/2","ref":"Ethers.Contracts.ERC721.html#set_approval_for_all/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `supportsInterface(bytes4 interfaceId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.supports_interface/1","ref":"Ethers.Contracts.ERC721.html#supports_interface/1"},{"type":"function","doc":"- interfaceId: `{:bytes, 4}`","title":"Function Parameter Types - Ethers.Contracts.ERC721.supports_interface/1","ref":"Ethers.Contracts.ERC721.html#supports_interface/1-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.supports_interface/1","ref":"Ethers.Contracts.ERC721.html#supports_interface/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `symbol()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.symbol/0","ref":"Ethers.Contracts.ERC721.html#symbol/0"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.symbol/0","ref":"Ethers.Contracts.ERC721.html#symbol/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `tokenURI(uint256 tokenId)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC721.token_uri/1","ref":"Ethers.Contracts.ERC721.html#token_uri/1"},{"type":"function","doc":"- tokenId: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC721.token_uri/1","ref":"Ethers.Contracts.ERC721.html#token_uri/1-function-parameter-types"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.token_uri/1","ref":"Ethers.Contracts.ERC721.html#token_uri/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `transferFrom(address from, address to, uint256 tokenId)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC721.transfer_from/3","ref":"Ethers.Contracts.ERC721.html#transfer_from/3"},{"type":"function","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC721.transfer_from/3","ref":"Ethers.Contracts.ERC721.html#transfer_from/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC721.transfer_from/3","ref":"Ethers.Contracts.ERC721.html#transfer_from/3-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"ERC777 token interface\n\nMore info: https://ethereum.org/en/developers/docs/standards/tokens/erc-777/","title":"Ethers.Contracts.ERC777","ref":"Ethers.Contracts.ERC777.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.ERC777.__default_address__/0","ref":"Ethers.Contracts.ERC777.html#__default_address__/0"},{"type":"function","doc":"Prepares `allowance(address holder, address spender)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.allowance/2","ref":"Ethers.Contracts.ERC777.html#allowance/2"},{"type":"function","doc":"- holder: `:address`\n - spender: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC777.allowance/2","ref":"Ethers.Contracts.ERC777.html#allowance/2-function-parameter-types"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.allowance/2","ref":"Ethers.Contracts.ERC777.html#allowance/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `approve(address spender, uint256 value)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.approve/2","ref":"Ethers.Contracts.ERC777.html#approve/2"},{"type":"function","doc":"- spender: `:address`\n - value: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC777.approve/2","ref":"Ethers.Contracts.ERC777.html#approve/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.approve/2","ref":"Ethers.Contracts.ERC777.html#approve/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `authorizeOperator(address operator)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.authorize_operator/1","ref":"Ethers.Contracts.ERC777.html#authorize_operator/1"},{"type":"function","doc":"- operator: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC777.authorize_operator/1","ref":"Ethers.Contracts.ERC777.html#authorize_operator/1-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.authorize_operator/1","ref":"Ethers.Contracts.ERC777.html#authorize_operator/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `balanceOf(address tokenHolder)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.balance_of/1","ref":"Ethers.Contracts.ERC777.html#balance_of/1"},{"type":"function","doc":"- tokenHolder: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC777.balance_of/1","ref":"Ethers.Contracts.ERC777.html#balance_of/1-function-parameter-types"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.balance_of/1","ref":"Ethers.Contracts.ERC777.html#balance_of/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `burn(uint256 amount, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.burn/2","ref":"Ethers.Contracts.ERC777.html#burn/2"},{"type":"function","doc":"- amount: `{:uint, 256}`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ERC777.burn/2","ref":"Ethers.Contracts.ERC777.html#burn/2-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.burn/2","ref":"Ethers.Contracts.ERC777.html#burn/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.ERC777.constructor/3","ref":"Ethers.Contracts.ERC777.html#constructor/3"},{"type":"function","doc":"- name_: `:string`\n - symbol_: `:string`\n - defaultOperators_: `{:array, :address}`","title":"Parameters - Ethers.Contracts.ERC777.constructor/3","ref":"Ethers.Contracts.ERC777.html#constructor/3-parameters"},{"type":"function","doc":"Prepares `decimals()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `pure`","title":"Ethers.Contracts.ERC777.decimals/0","ref":"Ethers.Contracts.ERC777.html#decimals/0"},{"type":"function","doc":"- `{:uint, 8}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.decimals/0","ref":"Ethers.Contracts.ERC777.html#decimals/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `defaultOperators()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.default_operators/0","ref":"Ethers.Contracts.ERC777.html#default_operators/0"},{"type":"function","doc":"- `{:array, :address}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.default_operators/0","ref":"Ethers.Contracts.ERC777.html#default_operators/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `granularity()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.granularity/0","ref":"Ethers.Contracts.ERC777.html#granularity/0"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.granularity/0","ref":"Ethers.Contracts.ERC777.html#granularity/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `isOperatorFor(address operator, address tokenHolder)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.is_operator_for/2","ref":"Ethers.Contracts.ERC777.html#is_operator_for/2"},{"type":"function","doc":"- operator: `:address`\n - tokenHolder: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC777.is_operator_for/2","ref":"Ethers.Contracts.ERC777.html#is_operator_for/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.is_operator_for/2","ref":"Ethers.Contracts.ERC777.html#is_operator_for/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `name()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.name/0","ref":"Ethers.Contracts.ERC777.html#name/0"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.name/0","ref":"Ethers.Contracts.ERC777.html#name/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `operatorBurn(address account, uint256 amount, bytes data, bytes operatorData)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.operator_burn/4","ref":"Ethers.Contracts.ERC777.html#operator_burn/4"},{"type":"function","doc":"- account: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ERC777.operator_burn/4","ref":"Ethers.Contracts.ERC777.html#operator_burn/4-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.operator_burn/4","ref":"Ethers.Contracts.ERC777.html#operator_burn/4-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `operatorSend(address sender, address recipient, uint256 amount, bytes data, bytes operatorData)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.operator_send/5","ref":"Ethers.Contracts.ERC777.html#operator_send/5"},{"type":"function","doc":"- sender: `:address`\n - recipient: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ERC777.operator_send/5","ref":"Ethers.Contracts.ERC777.html#operator_send/5-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.operator_send/5","ref":"Ethers.Contracts.ERC777.html#operator_send/5-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `revokeOperator(address operator)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.revoke_operator/1","ref":"Ethers.Contracts.ERC777.html#revoke_operator/1"},{"type":"function","doc":"- operator: `:address`","title":"Function Parameter Types - Ethers.Contracts.ERC777.revoke_operator/1","ref":"Ethers.Contracts.ERC777.html#revoke_operator/1-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.revoke_operator/1","ref":"Ethers.Contracts.ERC777.html#revoke_operator/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `send(address recipient, uint256 amount, bytes data)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.send/3","ref":"Ethers.Contracts.ERC777.html#send/3"},{"type":"function","doc":"- recipient: `:address`\n - amount: `{:uint, 256}`\n - data: `:bytes`","title":"Function Parameter Types - Ethers.Contracts.ERC777.send/3","ref":"Ethers.Contracts.ERC777.html#send/3-function-parameter-types"},{"type":"function","doc":"This function does not return any values!","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.send/3","ref":"Ethers.Contracts.ERC777.html#send/3-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `symbol()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.symbol/0","ref":"Ethers.Contracts.ERC777.html#symbol/0"},{"type":"function","doc":"- `:string`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.symbol/0","ref":"Ethers.Contracts.ERC777.html#symbol/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `totalSupply()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.ERC777.total_supply/0","ref":"Ethers.Contracts.ERC777.html#total_supply/0"},{"type":"function","doc":"- `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.total_supply/0","ref":"Ethers.Contracts.ERC777.html#total_supply/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `transfer(address recipient, uint256 amount)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.transfer/2","ref":"Ethers.Contracts.ERC777.html#transfer/2"},{"type":"function","doc":"- recipient: `:address`\n - amount: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC777.transfer/2","ref":"Ethers.Contracts.ERC777.html#transfer/2-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.transfer/2","ref":"Ethers.Contracts.ERC777.html#transfer/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `transferFrom(address holder, address recipient, uint256 amount)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nNo amount of Ether can be sent with this function.\n\n\nState mutability: `non_payable`","title":"Ethers.Contracts.ERC777.transfer_from/3","ref":"Ethers.Contracts.ERC777.html#transfer_from/3"},{"type":"function","doc":"- holder: `:address`\n - recipient: `:address`\n - amount: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.ERC777.transfer_from/3","ref":"Ethers.Contracts.ERC777.html#transfer_from/3-function-parameter-types"},{"type":"function","doc":"- `:bool`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.ERC777.transfer_from/3","ref":"Ethers.Contracts.ERC777.html#transfer_from/3-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"Multicall3 token interface\n\nMore info: https://www.multicall3.com","title":"Ethers.Contracts.Multicall3","ref":"Ethers.Contracts.Multicall3.html"},{"type":"function","doc":"Default address of the contract. Returns `nil` if not specified.\n\nTo specify a default address see `Ethers.Contract`","title":"Ethers.Contracts.Multicall3.__default_address__/0","ref":"Ethers.Contracts.Multicall3.html#__default_address__/0"},{"type":"function","doc":"Prepares `aggregate3((address,bool,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","title":"Ethers.Contracts.Multicall3.aggregate3/1","ref":"Ethers.Contracts.Multicall3.html#aggregate3/1"},{"type":"function","doc":"- calls: `{:array, {:tuple, [:address, :bool, :bytes]}}`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.aggregate3/1","ref":"Ethers.Contracts.Multicall3.html#aggregate3/1-function-parameter-types"},{"type":"function","doc":"- returnData: `{:array, {:tuple, [:bool, :bytes]}}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.aggregate3/1","ref":"Ethers.Contracts.Multicall3.html#aggregate3/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `aggregate3Value((address,bool,uint256,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","title":"Ethers.Contracts.Multicall3.aggregate3_value/1","ref":"Ethers.Contracts.Multicall3.html#aggregate3_value/1"},{"type":"function","doc":"- calls: `{:array, {:tuple, [:address, :bool, {:uint, 256}, :bytes]}}`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.aggregate3_value/1","ref":"Ethers.Contracts.Multicall3.html#aggregate3_value/1-function-parameter-types"},{"type":"function","doc":"- returnData: `{:array, {:tuple, [:bool, :bytes]}}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.aggregate3_value/1","ref":"Ethers.Contracts.Multicall3.html#aggregate3_value/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `aggregate((address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","title":"Ethers.Contracts.Multicall3.aggregate/1","ref":"Ethers.Contracts.Multicall3.html#aggregate/1"},{"type":"function","doc":"- calls: `{:array, {:tuple, [:address, :bytes]}}`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.aggregate/1","ref":"Ethers.Contracts.Multicall3.html#aggregate/1-function-parameter-types"},{"type":"function","doc":"- blockNumber: `{:uint, 256}`\n - returnData: `{:array, :bytes}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.aggregate/1","ref":"Ethers.Contracts.Multicall3.html#aggregate/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `blockAndAggregate((address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","title":"Ethers.Contracts.Multicall3.block_and_aggregate/1","ref":"Ethers.Contracts.Multicall3.html#block_and_aggregate/1"},{"type":"function","doc":"- calls: `{:array, {:tuple, [:address, :bytes]}}`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.block_and_aggregate/1","ref":"Ethers.Contracts.Multicall3.html#block_and_aggregate/1-function-parameter-types"},{"type":"function","doc":"- blockNumber: `{:uint, 256}`\n - blockHash: `{:bytes, 32}`\n - returnData: `{:array, {:tuple, [:bool, :bytes]}}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.block_and_aggregate/1","ref":"Ethers.Contracts.Multicall3.html#block_and_aggregate/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares contract constructor values for deployment.\n\nTo deploy a contracts use `Ethers.deploy/2` and pass the result of this function as\n`:encoded_constructor` option.","title":"Ethers.Contracts.Multicall3.constructor/0","ref":"Ethers.Contracts.Multicall3.html#constructor/0"},{"type":"function","doc":"","title":"Parameters - Ethers.Contracts.Multicall3.constructor/0","ref":"Ethers.Contracts.Multicall3.html#constructor/0-parameters"},{"type":"function","doc":"Prepares `getBasefee()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_basefee/0","ref":"Ethers.Contracts.Multicall3.html#get_basefee/0"},{"type":"function","doc":"- basefee: `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_basefee/0","ref":"Ethers.Contracts.Multicall3.html#get_basefee/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getBlockHash(uint256 blockNumber)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_block_hash/1","ref":"Ethers.Contracts.Multicall3.html#get_block_hash/1"},{"type":"function","doc":"- blockNumber: `{:uint, 256}`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.get_block_hash/1","ref":"Ethers.Contracts.Multicall3.html#get_block_hash/1-function-parameter-types"},{"type":"function","doc":"- blockHash: `{:bytes, 32}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_block_hash/1","ref":"Ethers.Contracts.Multicall3.html#get_block_hash/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getBlockNumber()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_block_number/0","ref":"Ethers.Contracts.Multicall3.html#get_block_number/0"},{"type":"function","doc":"- blockNumber: `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_block_number/0","ref":"Ethers.Contracts.Multicall3.html#get_block_number/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getChainId()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_chain_id/0","ref":"Ethers.Contracts.Multicall3.html#get_chain_id/0"},{"type":"function","doc":"- chainid: `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_chain_id/0","ref":"Ethers.Contracts.Multicall3.html#get_chain_id/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getCurrentBlockCoinbase()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_current_block_coinbase/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_coinbase/0"},{"type":"function","doc":"- coinbase: `:address`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_coinbase/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_coinbase/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getCurrentBlockDifficulty()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_current_block_difficulty/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_difficulty/0"},{"type":"function","doc":"- difficulty: `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_difficulty/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_difficulty/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getCurrentBlockGasLimit()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_current_block_gas_limit/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_gas_limit/0"},{"type":"function","doc":"- gaslimit: `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_gas_limit/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_gas_limit/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getCurrentBlockTimestamp()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_current_block_timestamp/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_timestamp/0"},{"type":"function","doc":"- timestamp: `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_current_block_timestamp/0","ref":"Ethers.Contracts.Multicall3.html#get_current_block_timestamp/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getEthBalance(address addr)` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_eth_balance/1","ref":"Ethers.Contracts.Multicall3.html#get_eth_balance/1"},{"type":"function","doc":"- addr: `:address`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.get_eth_balance/1","ref":"Ethers.Contracts.Multicall3.html#get_eth_balance/1-function-parameter-types"},{"type":"function","doc":"- balance: `{:uint, 256}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_eth_balance/1","ref":"Ethers.Contracts.Multicall3.html#get_eth_balance/1-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `getLastBlockHash()` call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on its own. (Use `Ethers.call/2`)\n\n\nState mutability: `view`","title":"Ethers.Contracts.Multicall3.get_last_block_hash/0","ref":"Ethers.Contracts.Multicall3.html#get_last_block_hash/0"},{"type":"function","doc":"- blockHash: `{:bytes, 32}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.get_last_block_hash/0","ref":"Ethers.Contracts.Multicall3.html#get_last_block_hash/0-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `tryAggregate(bool requireSuccess, (address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","title":"Ethers.Contracts.Multicall3.try_aggregate/2","ref":"Ethers.Contracts.Multicall3.html#try_aggregate/2"},{"type":"function","doc":"- requireSuccess: `:bool`\n - calls: `{:array, {:tuple, [:address, :bytes]}}`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.try_aggregate/2","ref":"Ethers.Contracts.Multicall3.html#try_aggregate/2-function-parameter-types"},{"type":"function","doc":"- returnData: `{:array, {:tuple, [:bool, :bytes]}}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.try_aggregate/2","ref":"Ethers.Contracts.Multicall3.html#try_aggregate/2-return-types-when-called-with-ethers-call-2"},{"type":"function","doc":"Prepares `tryBlockAndAggregate(bool requireSuccess, (address,bytes)[] calls)` call parameters on the contract.\n\nThis function can be used for a transaction or additionally called for results (Use `Ethers.send_transaction/2`).\nIt also supports receiving ether from the transaction origin.\n\n\nState mutability: `payable`","title":"Ethers.Contracts.Multicall3.try_block_and_aggregate/2","ref":"Ethers.Contracts.Multicall3.html#try_block_and_aggregate/2"},{"type":"function","doc":"- requireSuccess: `:bool`\n - calls: `{:array, {:tuple, [:address, :bytes]}}`","title":"Function Parameter Types - Ethers.Contracts.Multicall3.try_block_and_aggregate/2","ref":"Ethers.Contracts.Multicall3.html#try_block_and_aggregate/2-function-parameter-types"},{"type":"function","doc":"- blockNumber: `{:uint, 256}`\n - blockHash: `{:bytes, 32}`\n - returnData: `{:array, {:tuple, [:bool, :bytes]}}`","title":"Return Types (when called with `Ethers.call/2`) - Ethers.Contracts.Multicall3.try_block_and_aggregate/2","ref":"Ethers.Contracts.Multicall3.html#try_block_and_aggregate/2-return-types-when-called-with-ethers-call-2"},{"type":"module","doc":"Events for `Ethers.Contracts.CcipRead`","title":"Ethers.Contracts.CcipRead.EventFilters","ref":"Ethers.Contracts.CcipRead.EventFilters.html"},{"type":"module","doc":"Events for `Ethers.Contracts.ENS`","title":"Ethers.Contracts.ENS.EventFilters","ref":"Ethers.Contracts.ENS.EventFilters.html"},{"type":"function","doc":"Create event filter for `ApprovalForAll(address owner, address operator, bool approved)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/2"},{"type":"function","doc":"- owner: `:address`\n - operator: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - approved: `:bool`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ENS.EventFilters.html#approval_for_all/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `NewOwner(bytes32 node, bytes32 label, address owner)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.EventFilters.new_owner/2","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - label: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.new_owner/2","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - owner: `:address`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.new_owner/2","ref":"Ethers.Contracts.ENS.EventFilters.html#new_owner/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `NewResolver(bytes32 node, address resolver)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.EventFilters.new_resolver/1","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.new_resolver/1","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - resolver: `:address`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.new_resolver/1","ref":"Ethers.Contracts.ENS.EventFilters.html#new_resolver/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `NewTTL(bytes32 node, uint64 ttl)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.EventFilters.new_ttl/1","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.new_ttl/1","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - ttl: `{:uint, 64}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.new_ttl/1","ref":"Ethers.Contracts.ENS.EventFilters.html#new_ttl/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `Transfer(bytes32 node, address owner)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.EventFilters.transfer/1","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.EventFilters.transfer/1","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - owner: `:address`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.EventFilters.transfer/1","ref":"Ethers.Contracts.ENS.EventFilters.html#transfer/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"module","doc":"Events for `Ethers.Contracts.ENS.ExtendedResolver`","title":"Ethers.Contracts.ENS.ExtendedResolver.EventFilters","ref":"Ethers.Contracts.ENS.ExtendedResolver.EventFilters.html"},{"type":"module","doc":"Events for `Ethers.Contracts.ENS.Resolver`","title":"Ethers.Contracts.ENS.Resolver.EventFilters","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html"},{"type":"function","doc":"Create event filter for `ABIChanged(bytes32 node, uint256 contentType)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - contentType: `{:uint, 256}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.abi_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#abi_changed/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `AddrChanged(bytes32 node, address a)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - a: `:address`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.addr_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#addr_changed/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `AddressChanged(bytes32 node, uint256 coinType, bytes newAddress)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - coinType: `{:uint, 256}`\n - newAddress: `:bytes`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.address_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#address_changed/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `AuthorisationChanged(bytes32 node, address owner, address target, bool isAuthorised)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/3","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/3"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - owner: `:address`\n - target: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/3","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/3-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - isAuthorised: `:bool`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.authorisation_changed/3","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#authorisation_changed/3-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `ContenthashChanged(bytes32 node, bytes hash)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - hash: `:bytes`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.contenthash_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#contenthash_changed/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `DNSRecordChanged(bytes32 node, bytes name, uint16 resource, bytes record)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - name: `:bytes`\n - resource: `{:uint, 16}`\n - record: `:bytes`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_changed/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `DNSRecordDeleted(bytes32 node, bytes name, uint16 resource)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - name: `:bytes`\n - resource: `{:uint, 16}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_record_deleted/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_record_deleted/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `DNSZoneCleared(bytes32 node)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.dns_zone_cleared/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#dns_zone_cleared/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `InterfaceChanged(bytes32 node, bytes4 interfaceID, address implementer)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - interfaceID: `{:bytes, 4}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - implementer: `:address`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.interface_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#interface_changed/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `NameChanged(bytes32 node, string name)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - name: `:string`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.name_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#name_changed/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `PubkeyChanged(bytes32 node, bytes32 x, bytes32 y)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/1"},{"type":"function","doc":"- node: `{:bytes, 32}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - x: `{:bytes, 32}`\n - y: `{:bytes, 32}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.pubkey_changed/1","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#pubkey_changed/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `TextChanged(bytes32 node, string indexedKey, string key)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/2"},{"type":"function","doc":"- node: `{:bytes, 32}`\n - indexedKey: `:string`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - key: `:string`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ENS.Resolver.EventFilters.text_changed/2","ref":"Ethers.Contracts.ENS.Resolver.EventFilters.html#text_changed/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"module","doc":"Events for `Ethers.Contracts.ERC1155`","title":"Ethers.Contracts.ERC1155.EventFilters","ref":"Ethers.Contracts.ERC1155.EventFilters.html"},{"type":"function","doc":"Create event filter for `ApprovalForAll(address account, address operator, bool approved)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC1155.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/2"},{"type":"function","doc":"- account: `:address`\n - operator: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - approved: `:bool`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ERC1155.EventFilters.html#approval_for_all/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `TransferBatch(address operator, address from, address to, uint256[] ids, uint256[] values)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC1155.EventFilters.transfer_batch/3","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/3"},{"type":"function","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.transfer_batch/3","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/3-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - ids: `{:array, {:uint, 256}}`\n - values: `{:array, {:uint, 256}}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.transfer_batch/3","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_batch/3-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `TransferSingle(address operator, address from, address to, uint256 id, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC1155.EventFilters.transfer_single/3","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/3"},{"type":"function","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.transfer_single/3","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/3-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - id: `{:uint, 256}`\n - value: `{:uint, 256}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.transfer_single/3","ref":"Ethers.Contracts.ERC1155.EventFilters.html#transfer_single/3-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `URI(string value, uint256 id)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC1155.EventFilters.uri/1","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/1"},{"type":"function","doc":"- id: `{:uint, 256}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC1155.EventFilters.uri/1","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/1-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `:string`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC1155.EventFilters.uri/1","ref":"Ethers.Contracts.ERC1155.EventFilters.html#uri/1-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"module","doc":"Events for `Ethers.Contracts.ERC165`","title":"Ethers.Contracts.ERC165.EventFilters","ref":"Ethers.Contracts.ERC165.EventFilters.html"},{"type":"module","doc":"Events for `Ethers.Contracts.ERC20`","title":"Ethers.Contracts.ERC20.EventFilters","ref":"Ethers.Contracts.ERC20.EventFilters.html"},{"type":"function","doc":"Create event filter for `Approval(address owner, address spender, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC20.EventFilters.approval/2","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/2"},{"type":"function","doc":"- owner: `:address`\n - spender: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC20.EventFilters.approval/2","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC20.EventFilters.approval/2","ref":"Ethers.Contracts.ERC20.EventFilters.html#approval/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `Transfer(address from, address to, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC20.EventFilters.transfer/2","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/2"},{"type":"function","doc":"- from: `:address`\n - to: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC20.EventFilters.transfer/2","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC20.EventFilters.transfer/2","ref":"Ethers.Contracts.ERC20.EventFilters.html#transfer/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"module","doc":"Events for `Ethers.Contracts.ERC721`","title":"Ethers.Contracts.ERC721.EventFilters","ref":"Ethers.Contracts.ERC721.EventFilters.html"},{"type":"function","doc":"Create event filter for `Approval(address owner, address approved, uint256 tokenId)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC721.EventFilters.approval/3","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/3"},{"type":"function","doc":"- owner: `:address`\n - approved: `:address`\n - tokenId: `{:uint, 256}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC721.EventFilters.approval/3","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/3-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC721.EventFilters.approval/3","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval/3-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `ApprovalForAll(address owner, address operator, bool approved)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC721.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/2"},{"type":"function","doc":"- owner: `:address`\n - operator: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC721.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - approved: `:bool`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC721.EventFilters.approval_for_all/2","ref":"Ethers.Contracts.ERC721.EventFilters.html#approval_for_all/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `Transfer(address from, address to, uint256 tokenId)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC721.EventFilters.transfer/3","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/3"},{"type":"function","doc":"- from: `:address`\n - to: `:address`\n - tokenId: `{:uint, 256}`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC721.EventFilters.transfer/3","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/3-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC721.EventFilters.transfer/3","ref":"Ethers.Contracts.ERC721.EventFilters.html#transfer/3-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"module","doc":"Events for `Ethers.Contracts.ERC777`","title":"Ethers.Contracts.ERC777.EventFilters","ref":"Ethers.Contracts.ERC777.EventFilters.html"},{"type":"function","doc":"Create event filter for `Approval(address owner, address spender, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC777.EventFilters.approval/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/2"},{"type":"function","doc":"- owner: `:address`\n - spender: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.approval/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.approval/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#approval/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `AuthorizedOperator(address operator, address tokenHolder)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC777.EventFilters.authorized_operator/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/2"},{"type":"function","doc":"- operator: `:address`\n - tokenHolder: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.authorized_operator/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.authorized_operator/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#authorized_operator/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `Burned(address operator, address from, uint256 amount, bytes data, bytes operatorData)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC777.EventFilters.burned/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/2"},{"type":"function","doc":"- operator: `:address`\n - from: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.burned/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.burned/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#burned/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `Minted(address operator, address to, uint256 amount, bytes data, bytes operatorData)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC777.EventFilters.minted/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/2"},{"type":"function","doc":"- operator: `:address`\n - to: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.minted/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.minted/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#minted/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `RevokedOperator(address operator, address tokenHolder)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC777.EventFilters.revoked_operator/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/2"},{"type":"function","doc":"- operator: `:address`\n - tokenHolder: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.revoked_operator/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\nThis event does not contain any values!","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.revoked_operator/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#revoked_operator/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `Sent(address operator, address from, address to, uint256 amount, bytes data, bytes operatorData)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC777.EventFilters.sent/3","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/3"},{"type":"function","doc":"- operator: `:address`\n - from: `:address`\n - to: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.sent/3","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/3-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - amount: `{:uint, 256}`\n - data: `:bytes`\n - operatorData: `:bytes`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.sent/3","ref":"Ethers.Contracts.ERC777.EventFilters.html#sent/3-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"function","doc":"Create event filter for `Transfer(address from, address to, uint256 value)`\n\nFor each indexed parameter you can either pass in the value you want to\nfilter or `nil` if you don't want to filter.","title":"Ethers.Contracts.ERC777.EventFilters.transfer/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/2"},{"type":"function","doc":"- from: `:address`\n - to: `:address`","title":"Parameter Types (Event indexed topics) - Ethers.Contracts.ERC777.EventFilters.transfer/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/2-parameter-types-event-indexed-topics"},{"type":"function","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n - value: `{:uint, 256}`","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Ethers.Contracts.ERC777.EventFilters.transfer/2","ref":"Ethers.Contracts.ERC777.EventFilters.html#transfer/2-event-data-types-when-called-with-ethers-get_logs-2"},{"type":"module","doc":"Events for `Ethers.Contracts.Multicall3`","title":"Ethers.Contracts.Multicall3.EventFilters","ref":"Ethers.Contracts.Multicall3.EventFilters.html"},{"type":"behaviour","doc":"Signer behaviour.\n\nA signer module is (at least) capable of signing transactions and listing accounts in the signer.","title":"Ethers.Signer","ref":"Ethers.Signer.html"},{"type":"behaviour","doc":"Ethers ships with some default signers that you can use.\n\n- `Ethers.Signer.JsonRPC`: Can be used with most wallets, geth, web3signer or any other platform\n  which exposes a JsonRPC endpoint and implements `eth_signTransaction` and `eth_accounts`\n  functions.\n- `Ethers.Signer.Local`: This signs transactions locally but is highly discouraged to use in\n  a production environment as it does not have any security measures built in.","title":"Builtin Signers - Ethers.Signer","ref":"Ethers.Signer.html#module-builtin-signers"},{"type":"behaviour","doc":"Custom signers can also be implemented which must adhere to this behvaviour.\n\nFor signing transactions in custom signers the functions in `Ethers.Transaction` module might\nbecome handy. Check out the source code of built in signers for in depth info.","title":"Custom Signers - Ethers.Signer","ref":"Ethers.Signer.html#module-custom-signers"},{"type":"behaviour","doc":"If desired, a signer can be configured to be used for all operations in Ethers using elixir\nconfig.\n\n```elixir\nconfig :ethers,\n  default_signer: Ethers.Signer.JsonRPC,\n  default_signer_opts: [url: \"...\"]\n```","title":"Globally Default Signer - Ethers.Signer","ref":"Ethers.Signer.html#module-globally-default-signer"},{"type":"callback","doc":"Returns the available signer account addresses.\n\nThis method might not be supported by all signers. If a signer does not support this function\nit should return `{:error, :not_supported}`.","title":"Ethers.Signer.accounts/1","ref":"Ethers.Signer.html#c:accounts/1"},{"type":"callback","doc":"- opts: Other options passed to the signer as `signer_opts`","title":"Parameters - Ethers.Signer.accounts/1","ref":"Ethers.Signer.html#c:accounts/1-parameters"},{"type":"callback","doc":"Signs a binary and returns the signature","title":"Ethers.Signer.sign_transaction/2","ref":"Ethers.Signer.html#c:sign_transaction/2"},{"type":"callback","doc":"- tx: The transaction object. (An `Ethers.Transaction` struct)\n - opts: Other options passed to the signer as `signer_opts`.","title":"Parameters - Ethers.Signer.sign_transaction/2","ref":"Ethers.Signer.html#c:sign_transaction/2-parameters"},{"type":"module","doc":"Signer capable of signing transactions with a JSON RPC server\ncapable of `eth_signTransaction` and `eth_accounts` RPC functions.","title":"Ethers.Signer.JsonRPC","ref":"Ethers.Signer.JsonRPC.html"},{"type":"module","doc":"- `:rpc_module`: The RPC Module to use. (Optional, Defaults to `Ethereumex.HttpClient`)\n- `:url`: The RPC URL to use. (Optional)\n\n** All other options will be passed to the RPC module `request/3` function in\nthe third argument **","title":"Signer Options - Ethers.Signer.JsonRPC","ref":"Ethers.Signer.JsonRPC.html#module-signer-options"},{"type":"module","doc":"Local signer works with a private key.\n\nIMPORTANT: Please note that using this signer is discouraged in production\nenvironment since handling private keys in those environment can be challenging\nif you don't know what you are doing.","title":"Ethers.Signer.Local","ref":"Ethers.Signer.Local.html"},{"type":"module","doc":"- `:private_key`: The private key to use for signing and calculating account address.\n   Private key can either be in binary format (32 bytes) or it's hex encoded format with or\n   without `0x` prefix.","title":"Signer Options - Ethers.Signer.Local","ref":"Ethers.Signer.Local.html#module-signer-options"},{"type":"module","doc":"Error struct for `error OffchainLookup`","title":"Ethers.Contracts.CcipRead.Errors.OffchainLookup","ref":"Ethers.Contracts.CcipRead.Errors.OffchainLookup.html"},{"type":"type","doc":"","title":"Ethers.Contracts.CcipRead.Errors.OffchainLookup.t/0","ref":"Ethers.Contracts.CcipRead.Errors.OffchainLookup.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC1155InsufficientBalance`","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance.t/0","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InsufficientBalance.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC1155InvalidApprover`","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover.t/0","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidApprover.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC1155InvalidArrayLength`","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength.t/0","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidArrayLength.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC1155InvalidOperator`","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator.t/0","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidOperator.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC1155InvalidReceiver`","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver.t/0","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidReceiver.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC1155InvalidSender`","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender.t/0","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155InvalidSender.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC1155MissingApprovalForAll`","title":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll.t/0","ref":"Ethers.Contracts.ERC1155.Errors.ERC1155MissingApprovalForAll.html#t:t/0"},{"type":"exception","doc":"","title":"Ethers.Contracts.ERC165.Errors.NotERC165CompatibleError","ref":"Ethers.Contracts.ERC165.Errors.NotERC165CompatibleError.html"},{"type":"module","doc":"Error struct for `error ERC20InsufficientAllowance`","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance.t/0","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientAllowance.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC20InsufficientBalance`","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance.t/0","ref":"Ethers.Contracts.ERC20.Errors.ERC20InsufficientBalance.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC20InvalidApprover`","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover.t/0","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidApprover.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC20InvalidReceiver`","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver.t/0","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidReceiver.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC20InvalidSender`","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender.t/0","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSender.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC20InvalidSpender`","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender.t/0","ref":"Ethers.Contracts.ERC20.Errors.ERC20InvalidSpender.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721IncorrectOwner`","title":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner","ref":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721IncorrectOwner.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721InsufficientApproval`","title":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval","ref":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721InsufficientApproval.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721InvalidApprover`","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidApprover.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721InvalidOperator`","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOperator.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721InvalidOwner`","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidOwner.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721InvalidReceiver`","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidReceiver.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721InvalidSender`","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721InvalidSender.html#t:t/0"},{"type":"module","doc":"Error struct for `error ERC721NonexistentToken`","title":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken","ref":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken.html"},{"type":"type","doc":"","title":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken.t/0","ref":"Ethers.Contracts.ERC721.Errors.ERC721NonexistentToken.html#t:t/0"},{"type":"exception","doc":"Execution Error Exception.\n\nThe Exception struct will have these values:\n\n- `message`: Human readable error message\n- `evm_error`: A custom error from the contract. (An Error Struct)","title":"Ethers.ExecutionError","ref":"Ethers.ExecutionError.html"},{"type":"extras","doc":"# Elixir Ethers\n\n[![example workflow](https://github.com/ExWeb3/elixir_ethers/actions/workflows/elixir.yml/badge.svg)](https://github.com/ExWeb3/elixir_ethers)\n[![Coverage Status](https://coveralls.io/repos/github/ExWeb3/elixir_ethers/badge.svg?branch=main)](https://coveralls.io/github/ExWeb3/elixir_ethers?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/ethers.svg)](https://hex.pm/packages/ethers)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ethers/)\n[![License](https://img.shields.io/hexpm/l/ethers.svg)](https://github.com/ExWeb3/elixir_ethers/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/ExWeb3/elixir_ethers.svg)](https://github.com/ExWeb3/elixir_ethers/commits/main)\n\nEthers is a powerful Web3 library for Elixir that makes interacting with Ethereum and other\nEVM-based blockchains simple and intuitive.\nIt leverages Elixir's metaprogramming capabilities to provide a seamless developer experience.","title":"Introduction","ref":"readme.html"},{"type":"extras","doc":"- **Smart Contract Integration**: Generate Elixir modules from contract ABIs with full documentation\n- **Built-in Contracts**: Ready-to-use interfaces for [ERC20](https://hexdocs.pm/ethers/Ethers.Contracts.ERC20.html), [ERC721](https://hexdocs.pm/ethers/Ethers.Contracts.ERC721.html), [ERC1155](https://hexdocs.pm/ethers/Ethers.Contracts.ERC1155.html), and more\n- **Multi-chain Support**: Works with any EVM-compatible blockchain\n- **Flexible Signing**: Extensible signer support with [built-in ones](https://hexdocs.pm/ethers/readme.html#signing-transactions)\n- **Event Handling**: Easy filtering and retrieval of blockchain events\n- **Multicall Support**: Ability to easily perform multiple `eth_call`s using [Multicall 2/3](https://hexdocs.pm/ethers/Ethers.Multicall.html)\n- **Type Safety**: Native Elixir types for all contract interactions\n- **ENS Support**: Out of the box [Ethereum Name Service (ENS)](https://ens.domains/) support\n- **Comprehensive Documentation**: Auto-generated docs for all contract functions","title":"Key Features - Introduction","ref":"readme.html#key-features"},{"type":"extras","doc":"Add `ethers` to your dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ethers, \"~> 0.6.4\"},\n    # Uncomment next line if you want to use local signers\n    # {:ex_secp256k1, \"~> 0.7.2\"}\n  ]\nend\n```\n\nFor upgrading from versions prior to `0.6.0`, see our [Upgrade Guide](guides/upgrading.md).","title":"Installation - Introduction","ref":"readme.html#installation"},{"type":"extras","doc":"1. **Configure your RPC endpoint**:\n\n```elixir\n# config/config.exs\nconfig :ethereumex, url: \"https://eth.llamarpc.com\"\n```\n\n2. **Create a contract module**:\n\n```elixir\ndefmodule MyContract do\n  use Ethers.Contract,\n    abi_file: \"path/to/abi.json\",\n    default_address: \"0x...\" # Optional contract address\nend\n```\n\n3. **Start interacting with the blockchain**:\n\n```elixir\n# Read contract state\n{:ok, result} =\n  MyContract.my_function(\"0x...\")\n  |> Ethers.call()\n\n# Send a transaction\n{:ok, tx_hash} =\n  MyToken.my_function(\"0x...\", 1000)\n  |> Ethers.send_transaction(from: \"0x...\")\n```\n\nRead full documentation of Ethers for detailed information at [HexDocs](https://hexdocs.pm/ethers).","title":"Quick Start - Introduction","ref":"readme.html#quick-start"},{"type":"extras","doc":"","title":"Common Use Cases - Introduction","ref":"readme.html#common-use-cases"},{"type":"extras","doc":"```elixir\n# Single call\n{:ok, value} = MyContract.get_value() |> Ethers.call()\n\n# With parameters\n{:ok, balance} = MyToken.balance_of(address) |> Ethers.call()\n\n# Multiple calls using Multicall\n[{:ok, value1}, {:ok, value2}] = Ethers.Multicall.aggregate([\n  MyContract.get_value1(),\n  MyContract.get_value2()\n])\n```","title":"Reading Contract State - Introduction","ref":"readme.html#reading-contract-state"},{"type":"extras","doc":"```elixir\n# Simple transaction\n{:ok, tx_hash} = MyContract.set_value(123)\n                 |> Ethers.send_transaction(from: address, gas: 100_000)\n\n# With value transfer\n{:ok, tx_hash} = MyContract.deposit()\n                 |> Ethers.send_transaction(from: address, value: 1_000_000)\n```","title":"Writing to Contracts - Introduction","ref":"readme.html#writing-to-contracts"},{"type":"extras","doc":"```elixir\n# Create an event filter\nfilter = MyToken.EventFilters.transfer(from_address, nil)\n\n# Get matching events\n{:ok, events} = Ethers.get_logs(filter)\n```","title":"Working with Events - Introduction","ref":"readme.html#working-with-events"},{"type":"extras","doc":"Complete API documentation is available at [HexDocs](https://hexdocs.pm/ethers).\n\n- [Configuration Guide](guides/configuration.md) - Detailed configuration options\n- [Upgrade Guide](guides/upgrading.md) - Version upgrade instructions\n- [Built-in Contracts](#built-in-contract-interfaces-in-ethers) - Standard contract interfaces","title":"Documentation - Introduction","ref":"readme.html#documentation"},{"type":"extras","doc":"To get started with Ethers, you'll need to configure a JSON-RPC endpoint. Here's a minimal configuration:\n\n```elixir\n# Configure the JSON-RPC endpoint URL\nconfig :ethereumex, url: \"https://your-ethereum-node.com\"\n```\n\nYou can use one of the RPC URLs for your chain/wallet of choice or try out one from\n[chainlist.org](https://chainlist.org/).\n\nFor detailed configuration options, environment-specific setups, best practices, and\ntroubleshooting, please refer to our [Configuration Guide](guides/configuration.md).","title":"Configuration - Introduction","ref":"readme.html#configuration"},{"type":"extras","doc":"To use Elixir Ethers, you must have your contract's ABI in json format, which can be obtained from\n[etherscan.io](https://etherscan.io). This library also contains standard contract interfaces such\nas `ERC20`, `ERC721` and some more by default (refer to built-in contracts in\n[hexdocs](https://hexdocs.pm/ethers)).\n\nCreate a module for your contract as follows:\n\n```elixir\ndefmodule MyContract do\n  use Ethers.Contract,\n    abi_file: \"path/to/abi.json\",\n    default_address: \"0x[Contract address here (optional)]\"\n\n  # You can also add more code here in this module if you wish\nend\n```","title":"Custom ABIs - Introduction","ref":"readme.html#custom-abis"},{"type":"extras","doc":"After defining the module, all the functions can be called like any other Elixir module. These\nfunctions will return an `Ethers.TxData` struct which can be used later on to perform on-chain\ncalls or send transactions.\n\nTo fetch the results (return value(s)) of a function you can pass your function result to the\n[`Ethers.call/2`](https://hexdocs.pm/ethers/Ethers.html#call/2) function.\n\n#### Example\n\n```elixir\n# Calling functions on the blockchain\niex> MyContract.balance_of(\"0x[Address]\") |> Ethers.call()\n{:ok, 654294510138460920346}\n```\n\nRefer to [Ethers.call/2](https://hexdocs.pm/ethers/Ethers.html#call/2) for more information.","title":"Calling contract functions - Introduction","ref":"readme.html#calling-contract-functions"},{"type":"extras","doc":"To send transaction (eth_sendTransaction) to the blockchain, you can use the\n[`Ethers.send_transaction/2`](https://hexdocs.pm/ethers/Ethers.html#send_transaction/2) function.\n\nEnsure that you specify a `from` option to inform your client which account to use as the signer:\n\n#### Example\n\n```elixir\niex> MyContract.transfer(\"0x[Recipient]\", 1000) |> Ethers.send_transaction(from: \"0x[Sender]\")\n{:ok, \"0xf313ff7ff54c6db80ad44c3ad58f72ff0fea7ce88e5e9304991ebd35a6e76000\"}\n```\n\nRefer to [Ethers.send_transaction/2](https://hexdocs.pm/ethers/Ethers.html#send_transaction/2) for more information.","title":"Sending transaction - Introduction","ref":"readme.html#sending-transaction"},{"type":"extras","doc":"Ethers provides functionality for creating event filters and fetching related events from the\nblockchain. Each contract generated by Ethers also will have `EventFilters` module\n(e.g. `MyERC20Token.EventFilters`) that can be used to create filters for events.\n\nTo create an event filter and then use\n[`Ethers.get_logs/2`](https://hexdocs.pm/ethers/Ethers.html#get_logs/2) function like the below\nexample.\n\n#### Example\n\n```elixir\n# Create The Event Filter\n# (`nil` can be used for a parameter in EventFilters functions to indicate no filtering)\niex> filter = MyContract.EventFilters.transfer(\"0x[From Address Here]\", nil)\n\n# Then you can simply list the logs using `Ethers.get_logs/2`\n\niex> Ethers.get_logs(filter)\n{:ok,\n [\n   %Ethers.Event{\n     address: \"0x5883c66ca442461d406f330775d42954bfcf7d92\",\n     block_hash: \"0x83de67fd285067b838790406ea68f21a3afbc0ade534047725b5ccfb904c9ed3\",\n     block_number: 17077047,\n     topics: [\"Transfer(address,address,uint256)\",\n      \"0x6b75d8af000000e20b7a7ddf000ba900b4009a80\",\n      \"0x230507f6a391ae5ac0ec124f1c5b8ce454fe3f3d\"],\n     topics_raw: [\"0xddf252ad1be2c89b69c2b068fc378daa952ba7f163c4a11628f55a4df523b3ef\",\n      \"0x0000000000000000000000006b75d8af000000e20b7a7ddf000ba900b4009a80\",\n      \"0x000000000000000000000000230507f6a391ae5ac0ec124f1c5b8ce454fe3f3d\"],\n     transaction_hash: \"0xaa6fb2e1bbb27f667e76b03e8cde23db694207e06b9aa810d4c20c1f109a58e5\",\n     transaction_index: 0,\n     data: [761112156078097834180608],\n     log_index: 0,\n     removed: false\n   },\n   %Ethers.Event{...},\n    ...\n ]}\n```","title":"Getting Logs (Events) - Introduction","ref":"readme.html#getting-logs-events"},{"type":"extras","doc":"To resolve ENS or any other name service provider (which are ENS compatible) in the blockchain\nyou can simply use [`Ethers.NameService`](https://hexdocs.pm/ethers/Ethers.NameService.html) module.\n\n```elixir\niex> Ethers.NameService.resolve(\"vitalik.eth\")\n{:ok, \"0xd8da6bf26964af9d7eed9e03e53415d37aa96045\"}\n```","title":"Resolving Ethereum names (ENS domains) using Ethers - Introduction","ref":"readme.html#resolving-ethereum-names-ens-domains-using-ethers"},{"type":"extras","doc":"Ethers already includes some of the well-known contract interface standards for you to use.\nHere is a list of them.\n\n- [ERC20](https://hexdocs.pm/ethers/Ethers.Contracts.ERC20.html) - The well know fungible token standard\n- [ERC165](https://hexdocs.pm/ethers/Ethers.Contracts.ERC165.html) - Standard Interface detection\n- [ERC721](https://hexdocs.pm/ethers/Ethers.Contracts.ERC721.html) - Non-Fungible tokens (NFTs) standard\n- [ERC777](https://hexdocs.pm/ethers/Ethers.Contracts.ERC777.html) - Improved fungible token standard\n- [ERC1155](https://hexdocs.pm/ethers/Ethers.Contracts.ERC1155.html) - Multi-Token standard (Fungible, Non-Fungible or Semi-Fungible)\n- [Multicall](https://hexdocs.pm/ethers/Ethers.Multicall.html) - [Multicall3](https://www.multicall3.com/)\n\nTo use them you just need to specify the target contract address (`:to` option) of your token and\ncall the functions. Example:\n\n```elixir\niex> tx_data = Ethers.Contracts.ERC20.balance_of(\"0x[Holder Address]\")\n#Ethers.TxData \n\niex> Ethers.call(tx_data, to: \"0x[Token Address]\")\n{:ok, 123456}\n```","title":"Built-in contract ABIs in Ethers - Introduction","ref":"readme.html#built-in-contract-abis-in-ethers"},{"type":"extras","doc":"Ethers generates documentation for all the functions and event filters based on the ABI data.\nTo get the documentation you can either use the `h/1` IEx helper function or generate HTML/epub\ndocs using ExDoc.\n\n#### Get the documentation of a contract function\n\n```elixir\niex(3)> h MyERC20Token.balance_of\n\n                             def balance_of(owner)\n\n  @spec balance_of(Ethers.Types.t_address()) :: Ethers.TxData.t()\n\nPrepares balanceOf(address _owner) call parameters on the contract.\n\nThis function should only be called for result and never in a transaction on\nits own. (Use Ethers.call/2)\n\nState mutability: view","title":"Generated documentation for functions and event filters - Introduction","ref":"readme.html#generated-documentation-for-functions-and-event-filters"},{"type":"extras","doc":"• _owner: `:address`","title":"Function Parameter Types - Introduction","ref":"readme.html#function-parameter-types"},{"type":"extras","doc":"• balance: {:uint, 256}\n```\n\n#### Inspecting TxData and EventFilter structs\n\nOne cool and potentially useful feature of Ethers is how you can inspect the call\n\n#### Get the documentation of a event filter\n\n```elixir\niex(4)> h MyERC20Token.EventFilters.transfer\n\n                             def transfer(from, to)\n\n  @spec transfer(Ethers.Types.t_address(), Ethers.Types.t_address()) ::\n          Ethers.EventFilter.t()\n\nCreate event filter for Transfer(address from, address to, uint256 value)\n\nFor each indexed parameter you can either pass in the value you want to filter\nor nil if you don't want to filter.","title":"Return Types (when called with `Ethers.call/2`) - Introduction","ref":"readme.html#return-types-when-called-with-ethers-call-2"},{"type":"extras","doc":"• from: :address\n  • to: :address","title":"Parameter Types (Event indexed topics) - Introduction","ref":"readme.html#parameter-types-event-indexed-topics"},{"type":"extras","doc":"These are non-indexed topics (often referred to as data) of the event log.\n\n  • value: {:uint, 256}\n```","title":"Event `data` Types (when called with `Ethers.get_logs/2`) - Introduction","ref":"readme.html#event-data-types-when-called-with-ethers-get_logs-2"},{"type":"extras","doc":"By default, Ethers will rely on the default blockchain endpoint to handle the signing (using `eth_sendTransaction` RPC function). Obviously public endpoints cannot help you with signing the transactions since they do not hold your private keys.\n\nTo sign transactions on Ethers, You can specify a `signer` module when sending/signing transactions. A signer module is a module which implements the [Ethers.Signer](lib/ethers/signer.ex) behaviour.\n\nEthers has these built-in signers to use:\n\n- `Ethers.Signer.Local`: A local signer which loads a private key from `signer_opts` and signs the transactions.\n- `Ethers.Signer.JsonRPC`: Uses `eth_signTransaction` Json RPC function to sign transactions. (Using services like [Consensys/web3signer](https://github.com/Consensys/web3signer) or [geth](https://geth.ethereum.org/))\n\nFor more information on signers, visit [hexdocs](https://hexdocs.pm/ethers/Ethers.Signer.html).","title":"Signing Transactions - Introduction","ref":"readme.html#signing-transactions"},{"type":"extras","doc":"```elixir\nMyERC20Token.transfer(\"0x[Recipient]\", 1000)\n|> Ethers.send_transaction(\n  from: \"0x[Sender]\",\n  signer: Ethers.Signer.Local,\n  signer_opts: [private_key: \"0x...\"]\n)\n```","title":"Example - Introduction","ref":"readme.html#example"},{"type":"extras","doc":"`ex_keccak` is a Rustler NIF that brings keccak256 hashing to elixir.\nIt is the default used library in `ex_abi` and `ethers`. If for some reason you need to use a\ndifferent library (e.g. target does not support rustler) you can use the Application config value\nand on top of that set the environment variable `SKIP_EX_KECCAK=true` so ex_keccak is marked as\noptional in hex dependencies.\n\n```elixir\n# config.exs\nconfig :ethers, keccak_module: MyKeccakModule\n\n# Also make sure to set SKIP_EX_KECCAK=true when fetching dependencies and building them\n```","title":"Switching the ex_keccak library - Introduction","ref":"readme.html#switching-the-ex_keccak-library"},{"type":"extras","doc":"All contributions are very welcome (as simple as fixing typos). Please feel free to open issues and\npush Pull Requests. Just remember to be respectful to everyone!\n\nTo run the tests locally, follow below steps:\n\n- Install [ethereum](https://geth.ethereum.org/docs/getting-started/installing-geth) and [solc](https://docs.soliditylang.org/en/latest/installing-solidity.html). For example, on MacOS\n\n```\nbrew install ethereum\nnpm install -g solc\n```\n\n- Run [anvil (from foundry)](https://book.getfoundry.sh/getting-started/installation).\n  After installing anvil, just run the following in a new window\n\n```\n> anvil\n```\n\nThen you should be able to run tests through `mix test`.","title":"Contributing - Introduction","ref":"readme.html#contributing"},{"type":"extras","doc":"Ethers was possible to make thanks to the great contributors of the following libraries.\n\n- [ABI](https://github.com/poanetwork/ex_abi)\n- [Ethereumex](https://github.com/mana-ethereum/ethereumex)\n- [ExKeccak](https://github.com/tzumby/ex_keccak)\n\nAnd also all the people who contributed to this project in any ways.","title":"Acknowledgements - Introduction","ref":"readme.html#acknowledgements"},{"type":"extras","doc":"[Apache License 2.0](https://github.com/ExWeb3/elixir_ethers/blob/main/LICENSE)","title":"License - Introduction","ref":"readme.html#license"},{"type":"extras","doc":"# Changelog","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"","title":"v0.6.4 (2025-02-02) - Changelog","ref":"changelog.html#v0-6-4-2025-02-02"},{"type":"extras","doc":"- `Ethers.TxData` uses hex_decoded values instead of hex encoded ones","title":"Breaking Changes (Internal) - Changelog","ref":"changelog.html#breaking-changes-internal"},{"type":"extras","doc":"- Update `Ethers` module to RPCfy eth_call request params\n- Removed unnecessary hex decode/encodes in requests\n- Use `@external_resource` in generated contracts to track ABI changes and recompile if needed. (Thanks @sitch)","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.6.3 (2025-01-21) - Changelog","ref":"changelog.html#v0-6-3-2025-01-21"},{"type":"extras","doc":"- Strict type checking for initializing transaction structs","title":"Enahncements - Changelog","ref":"changelog.html#enahncements"},{"type":"extras","doc":"- Remove hexification of map entries in `Ethers.TxData.to_map/2`","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.6.2 (2025-01-10) - Changelog","ref":"changelog.html#v0-6-2-2025-01-10"},{"type":"extras","doc":"- Support [EIP-1191](https://eips.ethereum.org/EIPS/eip-1191): Add chain id to mixed-case checksum address encoding\n- Add [EIP-4844](https://eips.ethereum.org/EIPS/eip-4844) transaction support\n- Add [EIP-2930](https://eips.ethereum.org/EIPS/eip-2930) transaction support\n- Add `Ethers.blob_base_fee/1` to calculate blob fee per gas\n- Make default gas and fee margin configurable","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"- Fix encoding of transactions without any input data\n- Encode `access_list` and `blob_versioned_hashed` correctly in RPC transaction requests","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.6.1 (2025-01-02) - Changelog","ref":"changelog.html#v0-6-1-2025-01-02"},{"type":"extras","doc":"- Remove leading zeros from signature r and s values\n- Support hex decoded raw transaction in `Ethers.Transaction.decode/1`","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.6.0 (2025-01-01) - Changelog","ref":"changelog.html#v0-6-0-2025-01-01"},{"type":"extras","doc":"- Removed `Ethers.Transaction` struct and replaced with separate EIP-1559 and Legacy transaction structs for improved type safety\n- Deprecated `Ethers.Transaction.from_map/1` - use `Ethers.Transaction.from_rpc_map/1` instead for RPC response parsing\n- Deprecated `Ethers.Utils.maybe_add_gas_limit/2` - gas limits should now be set explicitly\n- Changed input format requirements: All inputs to `Ethers` functions must use native types (e.g., integers) instead of hex strings encoded values\n- Removed auto-gas estimation from send_transaction calls\n- `tx_type` option in transaction overrides has been replaced with `type`, now requiring explicit struct modules (e.g. `Ethers.Transaction.Eip1559`, `Ethers.Transaction.Legacy`)\n- Moved `Ethers.Transaction.calculate_y_parity_or_v/1` to `Ethers.Transaction.Signed` module\n- Deprecate `Ethers.send/2` in favor of `Ethers.send_transaction/2` for clarity and prevent collision with `Kernel.send/2`.","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"- Added **EIP-3668 CCIP-Read** support via `Ethers.CcipRead` module for off-chain data resolution\n- Extended NameService to handle off-chain and cross-chain name resolution using CCIP-Read protocol\n- Introduced `Ethers.Transaction.Protocol` behaviour for improved transaction handling\n- Added dedicated _EIP-1559_ and _Legacy_ transaction struct types with validation\n- New address utilities: `Ethers.Utils.decode_address/1` and `Ethers.Utils.encode_address/1`\n- Added `Transaction.decode/1` to decode raw transactions","title":"New features - Changelog","ref":"changelog.html#new-features"},{"type":"extras","doc":"- Improved error handling and reporting in `Ethers.deploy/2`\n- Enhanced NameService with ENSIP-10 wildcard resolution support\n- Use checksum addresses when decoding transactions\n- Add bang versions of `Ethers` top module functions which were missing","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.5.5 (2024-12-03) - Changelog","ref":"changelog.html#v0-5-5-2024-12-03"},{"type":"extras","doc":"- Add `from_block` and `to_block` options to `Ethers.get_logs/2`\n- Add RPC adapter behaviour and proxy for Ethereumex.HttpClient\n- Move and export abi decode functionality to `Ethers.TxData` module\n- Export `Ethers.TxData.to_map/2` in docs\n- Add `Ethers.Event.find_and_decode/2` function","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.5.4 (2024-10-22) - Changelog","ref":"changelog.html#v0-5-4-2024-10-22"},{"type":"extras","doc":"- Handle `nil` values when decoding transaction values for RLP encoding","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.5.3 (2024-10-14) - Changelog","ref":"changelog.html#v0-5-3-2024-10-14"},{"type":"extras","doc":"- Make event filter arguments optional in typespecs","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.5.2 (2024-08-08) - Changelog","ref":"changelog.html#v0-5-2-2024-08-08"},{"type":"extras","doc":"- Handle `{:ok, nil}` from RPC get block by number request","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"- Enable raw use of `Ethers.call/2` (usage without function selector)\n- Add optional backoff to `Ethers.Utils.date_to_block_number/3`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.5.1 (2024-08-02) - Changelog","ref":"changelog.html#v0-5-1-2024-08-02"},{"type":"extras","doc":"- Mark `ex_keccak` as optional using SKIP_EX_KECCAK environment variable","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.5.0 (2024-05-29) - Changelog","ref":"changelog.html#v0-5-0-2024-05-29"},{"type":"extras","doc":"- Rename `NotERC165CompatibleError` to `Errors.NotERC165CompatibleError`","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"- Handle unexpected errors in ExecutionError exceptions","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.4.5 (2024-04-27) - Changelog","ref":"changelog.html#v0-4-5-2024-04-27"},{"type":"extras","doc":"- Add `Ethers.NameService.reverse_resolve/2` to reverse resolve addresses to domains","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.4.4 (2024-04-17) - Changelog","ref":"changelog.html#v0-4-4-2024-04-17"},{"type":"extras","doc":"- Add ERC-165 contract and behaviour\n- Add `skip_docs` option for contract module doc and typespec generation\n- Allow skipping checksum address in `Ethers.Utils.public_key_to_address/2`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.4.3 (2024-04-05) - Changelog","ref":"changelog.html#v0-4-3-2024-04-05"},{"type":"extras","doc":"- Fix `Ethers.Multicall` typespecs","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.4.2 (2024-04-04) - Changelog","ref":"changelog.html#v0-4-2-2024-04-04"},{"type":"extras","doc":"- Support sending raw transactions using `Ethers.send/2`\n- Add `Ethers.get_transaction_count/2`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.4.1 (2024-04-02) - Changelog","ref":"changelog.html#v0-4-1-2024-04-02"},{"type":"extras","doc":"- Add support of getting current `max_priority_fee_per_gas`\n- Use latest `max_priority_fee_per_gas` from the chain as default value in transactions","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.4.0 (2024-03-11) - Changelog","ref":"changelog.html#v0-4-0-2024-03-11"},{"type":"extras","doc":"- Custom errors will be returned as error structs instead of raw RPC response\n- Updated ERC20, ERC721 and ERC1155 ABIs to Openzeppelin 5.x","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"- Generate error structs from ABI and decode custom errors when error data is available\n- Use JsonRPC signer as a default signer in `Ethers.sign_transaction/2`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.3.1 (2024-03-05) - Changelog","ref":"changelog.html#v0-3-1-2024-03-05"},{"type":"extras","doc":"- Fix trimmed zeros in transaction encoder with unified hex encoding for transaction","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.3.0 (2024-02-05) - Changelog","ref":"changelog.html#v0-3-0-2024-02-05"},{"type":"extras","doc":"- Removed `signature_v`, `signature_recovery_id` and `signature_y_parity` from `Ethers.Transaction`\n  struct and introduce new `signature_v_or_y_parity` value\n- Update `ex_abi` to 0.7.0 with new `method_id` logic for event selectors and use its value","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"- Cleanup implementation of Transaction encoders and value decoder","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.2.3 (2024-01-29) - Changelog","ref":"changelog.html#v0-2-3-2024-01-29"},{"type":"extras","doc":"- Add `Ethers.get_transaction_receipt/2` function to query native chain transaction receipt by transaction hash.","title":"New features - Changelog","ref":"changelog.html#new-features"},{"type":"extras","doc":"- Add more metadata to `Ethers.Transaction` struct.\n- Return `Ethers.Transaction` struct in `Ethers.get_transaction/2` function.\n- Support `get_transaction` in batch requests.","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.2.2 (2024-01-08) - Changelog","ref":"changelog.html#v0-2-2-2024-01-08"},{"type":"extras","doc":"- Add `Ethers.get_transaction/2` function to query native chain transaction by transaction hash.","title":"New features - Changelog","ref":"changelog.html#new-features"},{"type":"extras","doc":"","title":"v0.2.1 (2024-01-04) - Changelog","ref":"changelog.html#v0-2-1-2024-01-04"},{"type":"extras","doc":"- Add `Ethers.get_balance/2` function to query native chain balance of accounts.","title":"New features - Changelog","ref":"changelog.html#new-features"},{"type":"extras","doc":"- Encode integers to hex even when they are part of params","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.2.0 (2024-01-01) - Changelog","ref":"changelog.html#v0-2-0-2024-01-01"},{"type":"extras","doc":"- `Ethers.sign_transaction/2` function\n- Signer behaviour\n- Local Signer implementation\n- JsonRPC Signer implementation\n- `Ethers.Transaction` struct and helper functions","title":"New Features - Changelog","ref":"changelog.html#new-features"},{"type":"extras","doc":"","title":"v0.1.3 (2023-12-26) - Changelog","ref":"changelog.html#v0-1-3-2023-12-26"},{"type":"extras","doc":"- unsized integer encoding to hex will now raise if given negative numbers.\n- `Utils.date_to_block_number/3` going to negative block numbers issue fixed.","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.1.2 (2023-12-12) - Changelog","ref":"changelog.html#v0-1-2-2023-12-12"},{"type":"extras","doc":"- `TxData.to_map/2` now returns hex values for all integers.\n- `Utils.maybe_add_gas_limit/2` now adds hex gas limit value instead of integer.","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"","title":"v0.1.1 (2023-11-22) - Changelog","ref":"changelog.html#v0-1-1-2023-11-22"},{"type":"extras","doc":"- Multicall: aggregate_3 decoder returns `nil` in case of failure\n- Multicall: Feed decoded results through `Utils.human_arg/2`","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.1.0 (2023-11-19) - Changelog","ref":"changelog.html#v0-1-0-2023-11-19"},{"type":"extras","doc":"- Checksum address utility functions","title":"New Features - Changelog","ref":"changelog.html#new-features"},{"type":"extras","doc":"- Use zip_reduce for event generators\n- Move documentation generators to ContractHelpers\n- Display message for empty parameters or return types\n- `Ethers.call/2` and `Ethers.get_logs/2` now automatically convert integer block numbers to hex values\n- Return structs as a result in generated functions and event filter with Inspection protocols implemented for better development experience\n- Support dynamically sized indexed event filters (bytes, strings, arrays and structs)\n- `Ethers.call/2` now only returns as a list if the return type is either a solidity array or tuple\n- Add return names in documentations and TxData inspection\n- Added an interface for `Multicall3` through `Ethers.Contracts.Multicall3`\n- Added `Ethers.Multicall` as an abstraction for `Ethers.Contracts.Multicall3`\n- Added batching functionality using `Ethers.batch/2`","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"- The generated contract functions no longer call or send transactions, They will only prepare parameters\n  To execute an explicit call to `Ethers.send/2` or `Ethers.call/2` is required\n- Events no longer accept `address` overrides. Overriding now happens at `Ethers.get_logs/2`\n- Function `Ethers.get_logs/3` is now changed to `Ethers.get_logs/2`\n- Generated contract modules and EventFilter modules `default_address/0` function is now renamed to `__default_address__/0` to prevent collision\n- Removal of `Ethers.RPC` module\n- Remove `Ethers.Types.dynamically_sized_types/0` function\n- `Ethers.call/2` response is not always a list\n- `Ethers.deploy/4` is now removed and replaced with `Ethers.deploy/2`","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"- Fix event filters with mixed indexed and non-indexed arguments","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.0.6 (2023-09-06) - Changelog","ref":"changelog.html#v0-0-6-2023-09-06"},{"type":"extras","doc":"- Update `dialyxir` dependency to 1.4.0\n- Update `ex_doc` to 0.30.6\n- Add more function to `Utils` module\n- Improve failure return values of deployment functions","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"- Fix RPC options and client override issue\n- Do not add `nil` to address when address is not present","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.0.5 (2023-08-21) - Changelog","ref":"changelog.html#v0-0-5-2023-08-21"},{"type":"extras","doc":"- Add ENS (Ethereum name service) contracts and helper functions\n- Update `ex_doc` dependency to 0.30.4\n- Address `Logger.warn` deprecation","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.0.4 (2023-07-14) - Changelog","ref":"changelog.html#v0-0-4-2023-07-14"},{"type":"extras","doc":"- Update `ex_doc` dependency to 0.30.1\n- Update `jason` dependency to 1.4.1","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"","title":"v0.0.3 (2023-05-29) - Changelog","ref":"changelog.html#v0-0-3-2023-05-29"},{"type":"extras","doc":"- Improved generative documentation for modules\n- Improved gas estimation API\n- Add gas limit to sending transactions\n- Remove redundant gas estimation function","title":"Enhancements - Changelog","ref":"changelog.html#enhancements"},{"type":"extras","doc":"- Fix bitsize check guard to include all available solidity bitsizes","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"","title":"v0.0.2 (2023-04-24) - Changelog","ref":"changelog.html#v0-0-2-2023-04-24"},{"type":"extras","doc":"- Include the priv directory in mix releases","title":"Bug fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"First Release","title":"v0.0.1 (2023-04-24) - Changelog","ref":"changelog.html#v0-0-1-2023-04-24"},{"type":"extras","doc":"# Typed Arguments\n\nTyped arguments help Ethers with determining the exact function to use when there are multiple overloads of\nthe same function with same arity.","title":"Typed Arguments","ref":"typed-arguments.html"},{"type":"extras","doc":"In solidity, contract functions (and events) can be overloaded.\nThis means a function with the same name can be defined with different argument types and even different arities.","title":"Problem - Typed Arguments","ref":"typed-arguments.html#problem"},{"type":"extras","doc":"```solidity\ncontract Overloaded {\n    function transfer(uint256 amount) public pure returns (string memory) {\n        ...\n    }\n\n    function transfer(int256 amount) public pure returns (string memory) {\n        ...\n    }\n}\n```\n\nIn the above contract, the function transfer is once implemented with `uint256` and another time with `int256`.\n\nSince Elixir is dynamically typed, we need a way to specify which function we need to call in this scenario.","title":"Example - Typed Arguments","ref":"typed-arguments.html#example"},{"type":"extras","doc":"Ethers provides a simple helper function called `Ethers.Types.typed/2`. This function helps you with specifying the type for your parameter. It will help Ethers to know which function to select when you want to call it.\n\nLet's try it with the example contract above. If we assume we want to call the transfer function with `uint256` type, here is the code we need.\n\n```elixir\ndefmodule Overloaded do\n  use Ethers.Contract, abi: ...\nend\n\nOverloaded.transfer(Ethers.Types.typed({:uint, 256}, 100))\n|> Ethers.send_transaction!(...)\n```\n\nThis way we have explicitly told Ethers to use the `uint256` type for the first argument.","title":"Solution - Typed Arguments","ref":"typed-arguments.html#solution"},{"type":"extras","doc":"Ethers supports all generic data types from EVM. Here is a list of them.\n\n| Elixir Type              | Solidity Type     | Description                                         |\n| ------------------------ | ----------------- | --------------------------------------------------- |\n| `:address`               | `address`         | Ethereum wallet address                             |\n| `:bool`                  | `bool`            | Boolean value                                       |\n| `:string`                | `string`          | Dynamic length string                               |\n| `:bytes`                 | `bytes`           | Dynamic length byte array [^1]                      |\n| `{:bytes, size}`         | `bytes{size}`     | Fixed length byte array [^1]                        |\n| `{:uint, bitsize}`       | `uint{bitsize}`   | Unsigned integer [^2]                               |\n| `{:int, bitsize}`        | `int{bitsize}`    | Signed integer  [^2]                                |\n| `{:array, type}`         | `T[]`             | Dynamic length array of type                        |\n| `{:array, type, length}` | `T[{length}]`     | Fixed length array of type                          |\n| `{:tuple, types}`        | Tuples or Structs | A tuple with types (structs in solidity are tuples) |\n\n[^1]: For fixed length byte array (bytes1, bytes2, ..., bytes32) the size must be between 1 and 32.\n[^2]: For `int` and `uint` data types, the bitsize must be between 8 and 256 and also dividable to 8.","title":"Supported Types - Typed Arguments","ref":"typed-arguments.html#supported-types"},{"type":"extras","doc":"# Configuration Guide\n\nThis guide provides detailed information about configuring Ethers for your Elixir project. We'll cover all available configuration options, their purposes, and best practices for different scenarios.","title":"Configuration","ref":"configuration.html"},{"type":"extras","doc":"Ethers uses Ethereumex as an Ethereum RPC client by default. A default URL can be set using\nthe elixir config statements like the example below.\n\nYou can use one of the RPC URLs for your chain/wallet of choice or try out one of them from\n[chainlist.org](https://chainlist.org). We recommend using a reliable RPC provider (line infura\nor quicknodes) for production.\n\n```elixir\n# Configure the default JSON-RPC endpoint URL\nconfig :ethereumex, url: \"https://...\"\n```\n\nNote: If your app requires multiple RPC endpoints (e.g. multi-chain) then you need to pass in the\nURL for each operation via `:rpc_opts` key. (e.g. `Ethers.call(my_fn, rpc_opts: [url: \"https://...\"])`","title":"Json RPC Configuration - Configuration","ref":"configuration.html#json-rpc-configuration"},{"type":"extras","doc":"","title":"Configuration Options - Configuration","ref":"configuration.html#configuration-options"},{"type":"extras","doc":"Specifies the module responsible for making JSON-RPC calls to the Ethereum node. This module must implement\n`Ethers.RpcClient.Adapter` behaviour.\n\n#### Example\n\n```elixir\nconfig :ethers, rpc_client: Ethereumex.HttpClient\n```","title":"RPC Client `:rpc_client` - Configuration","ref":"configuration.html#rpc-client-rpc_client"},{"type":"extras","doc":"Module for Keccak-256 hashing operations. Uses `ExKeccak` by default.\n\n#### Example\n\n```elixir\nconfig :ethers, keccak_module: ExKeccak\n```","title":"Keccak Module `:keccak_module` - Configuration","ref":"configuration.html#keccak-module-keccak_module"},{"type":"extras","doc":"Handles JSON encoding/decoding. Uses `Jason` by default.\n\n#### Example\n\n```elixir\nconfig :ethers, json_module: Jason  # If you prefer using Poison\n```","title":"JSON Module `json_module` - Configuration","ref":"configuration.html#json-module-json_module"},{"type":"extras","doc":"Handles elliptic curve operations for signing and public key operations.\n\n```elixir\nconfig :ethers, secp256k1_module: ExSecp256k1\n```","title":"Secp256k1 Module `:secp256k1_module` - Configuration","ref":"configuration.html#secp256k1-module-secp256k1_module"},{"type":"extras","doc":"Specifies the default module for transaction signing by default.\nAlso use `default_signer_opts` as default signer options if needed (See example).\n\n#### Built-in Siginers\n\n- `Ethers.Signer.Local`: For local private key signing\n- `Ethers.Signer.JsonRPC`: For remote signing via RPC\n\n#### Example\n\n```elixir\nconfig :ethers,\n  default_signer: Ethers.Signer.Local,\n  default_signer_opts: [private_key: System.fetch_env!(\"ETH_PRIVATE_KEY\")]\n```","title":"Default Signer `:default_signer` and `:default_signer_opts` - Configuration","ref":"configuration.html#default-signer-default_signer-and-default_signer_opts"},{"type":"extras","doc":"#### Default Gas Margin `:default_gas_margin`\n\nSafety margin for gas estimation. Precision is 0.01%. Default is 11000 = 110%.\n\nThis will increase the estimated gas value so transactions are less likely to run out of gas.\n\n#### Example\n\n```elixir\nconfig :ethers, default_gas_margin: 11000  # 110% gas margin\n```\n\n#### Max Fee Per Gas Margin `:default_max_fee_per_gas_margin`\n\nSafety margin for max fee per gas in EIP-1559 transactions. Precision is 0.01%. Default is 12000 = 120%.\n\n```elixir\nconfig :ethers, default_max_fee_per_gas_margin: 12000  # 120% of current gas price.\n```","title":"Gas Margins - Configuration","ref":"configuration.html#gas-margins"},{"type":"extras","doc":"1. **Security**:\n\n   - Never commit private keys or sensitive configuration\n   - Use environment variables for sensitive values\n   - Consider using runtime configuration for flexibility\n\n2. **Gas Management**:\n\n   - Adjust gas margins based on network conditions\n   - Use higher margins on networks with more volatility\n\n3. **RPC Endpoints**:\n\n   - Use reliable RPC providers in production\n   - Consider fallback RPC endpoints\n   - Monitor RPC endpoint performance\n\n4. **Signing**:\n   - If possible, Use [ethers_kms](https://hexdocs.pm/ethers_kms) in production for better security\n   - Keep private keys secure when using `Ethers.Signer.Local`","title":"Best Practices - Configuration","ref":"configuration.html#best-practices"},{"type":"extras","doc":"","title":"Troubleshooting - Configuration","ref":"configuration.html#troubleshooting"},{"type":"extras","doc":"- **RPC Connection Issues**:\n\n```elixir\n# Verify your RPC connection\nconfig :ethereumex,\n  url: \"https://your-ethereum-node.com\",\n  http_options: [recv_timeout: 60_000]  # Increase timeout if needed\n```\n\n- **Gas Estimation Failures**:\n  Increase gas margin for complex contracts\n\n```elixir\nconfig :ethers, default_gas_margin: 15000  # 150%\n```\n\nOr manually provide the gas estimation when sending/signing transactions.","title":"Common Issues - Configuration","ref":"configuration.html#common-issues"},{"type":"extras","doc":"# Upgrade Guide\n\nThis guide provides information about upgrading between different versions of Ethers and handling breaking changes.","title":"Upgrading","ref":"upgrading.html"},{"type":"extras","doc":"Version 0.6.x and onwards introduce several breaking changes to improve type safety and explicitness.\nHere's what you need to know:","title":"Upgrading to 0.6.x - Upgrading","ref":"upgrading.html#upgrading-to-0-6-x"},{"type":"extras","doc":"#### Native Elixir Types\n\nAll inputs to functions now require native Elixir types\n\nExample: Use integers instead of hex strings\n```elixir\n# Before (0.5.x)\nEthers.call(ERC20.name(), gas: \"0x1\")\n\n# After (0.6.x)\nEthers.call(ERC20.name(), gas: 1)\n```\n\n#### Explicit Gas Limits\n\nWhen sending transactions without a signer, the gas limit (and no other field) will not be\nautomatically set. Only when using a signer, these values will be fetched from the network for you.\n\n```elixir\n# Before (0.5.x)\nMyContract.my_function() |> Ethers.send_transaction()\n\n# After (0.6.x)\nMyContract.my_function() |> Ethers.send_transaction(gas: 100_000)\n```\n\n#### Transaction Types\n\nTransaction struct split into separate EIP-1559, EIP-4844 and EIP-2930 and Legacy types.\n\n```elixir\n# Before (0.5.x)\nEthers.send_transaction(tx, tx_type: :eip1559)\n\n# After (0.6.x)\nEthers.send_transaction(tx, type: Ethers.Transaction.Eip1559)\n```","title":"Key Changes - Upgrading","ref":"upgrading.html#key-changes"},{"type":"extras","doc":"#### Transaction Sending\n\nUse `Ethers.send_transaction/2` instead of `Ethers.send/2`\n\n```elixir\n# Before (0.5.x)\nEthers.send(tx)\n\n# After (0.6.x)\nEthers.send_transaction(tx)\n```\n\n#### Transaction Creation\n\nUse `Ethers.Transaction.from_rpc_map/1` instead of `from_map/1`\n\n```elixir\n# Before (0.5.x)\nEthers.Transaction.from_map(tx_map)\n\n# After (0.6.x)\nEthers.Transaction.from_rpc_map(tx_map)\n```","title":"Function Changes - Upgrading","ref":"upgrading.html#function-changes"},{"type":"extras","doc":"1. [ ] Update all function inputs to use native Elixir types\n2. [ ] Add explicit gas limits to all transactions\n3. [ ] Update transaction type specifications\n4. [ ] Replace deprecated function calls\n5. [ ] Test all contract interactions","title":"Migration Checklist - Upgrading","ref":"upgrading.html#migration-checklist"},{"type":"extras","doc":"For upgrades from versions prior to 0.5.x, please refer to the [CHANGELOG.md](../CHANGELOG.md) file.","title":"Upgrading from Earlier Versions - Upgrading","ref":"upgrading.html#upgrading-from-earlier-versions"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}